@@ -251,8 +251,8 @@ public class CDFCompare extends JFrame
     }
 
     CDFCompare(JFrame parentDriver, String basecdf, boolean modal) {
-        if (basecdf != null) command = basecdf + separator + "bin" + 
-				       separator + "cdfcompare ";
+        if (basecdf != null) command = "\"" + basecdf + separator + "bin" + 
+				       separator + "cdfcompare\" ";
 	dialog = new JDialog(this, modal);
         this.modal = modal;
 	this.parentDriver = parentDriver;
