@@ -133,9 +133,20 @@ public class CDFConvert extends JFrame
     JRadioButton encoding14 = new JRadioButton("AlphaVMSi");
     JRadioButton encoding15 = new JRadioButton("AlphaOSF1");
 
+/** A group radio buttons for Epoch data type conversion. */
+    ButtonGroup epoch = new ButtonGroup();
+/** A group radio buttons for Epoch. */
+    JRadioButton epoch0 = new JRadioButton("None");
+    JRadioButton epoch1 = new JRadioButton("EPOCH/EPOCH16-TT2000");
+    JRadioButton epoch2 = new JRadioButton("TT2000-EPOCH");
+    JRadioButton epoch3 = new JRadioButton("TT2000-EPOCH16");
+
 /** A radio button panel for Encoding. */
     JPanel encodingPanel = new JPanel(true);
 
+/** A radio button panel for Epoch. */
+    JPanel epochPanel = new JPanel(true);
+
 /** "Enter" button. */
     JButton entrb = new JButton(" Enter ");
 /** "Help" button. */
@@ -179,6 +190,8 @@ public class CDFConvert extends JFrame
     JLabel FORMAT = new JLabel("Format:  ");
 /** A label of "Encoding:" for the combobox encoding. */
     JLabel ENCODING = new JLabel("Encoding:  ");
+/** A label of "Epoch:" for the combobox epoch. */
+    JLabel EPOCH = new JLabel("Epoch:  ");
 /** A label of "Majority:" for the combobox majority. */
     JLabel MAJORITY = new JLabel("Majority:  ");
 /** A label of "Sparseness:" for the text field sparseness. */
@@ -220,11 +233,14 @@ public class CDFConvert extends JFrame
     String strfm = "";
     String strsr = " ";
     String stren = "";
+    String strep = "";
     String strcs = "";
     String strsk = "";
     String strbw = " ";
+    String stret = " ";
     String strcks = "";
     String report, Zmode, Majority, Format, Encoding, caches, temp, Checksum;
+    String Epoch;
     String Caches = " ";
     String Compression = " ";
     String Sparseness = " ";
@@ -376,10 +392,6 @@ public class CDFConvert extends JFrame
         makeJButton(panel1, cdf2, 1, 2, 1, 1, 1.0, 1.0);
 	makeJButton(panel1, Box.createRigidArea(hpad10), 2, 2, 1, 1, 1.0, 1.0);
         makeJButton(panel1, slt2, 3, 2, 1, 1, 1.0, 1.0);
-//        makeJButton(panel1, SKLT, 0, 3, 1, 1, 1.0, 1.0);
-//        makeJButton(panel1, sklt, 1, 3, 1, 1, 1.0, 1.0);
-//	makeJButton(panel1, Box.createRigidArea(hpad10), 2, 3, 1, 1, 1.0, 1.0);
-//        makeJButton(panel1, slt3, 3, 3, 1, 1, 1.0, 1.0);
 	makeJButton(panel1, Box.createRigidArea(vpad20), 0, 3, 1, 1, 1.0, 1.0);
 
         cdf1.addActionListener(this);
@@ -580,7 +592,6 @@ public class CDFConvert extends JFrame
         encodingPanel.add(encoding6);
         encodingPanel.add(encoding7);
         encodingPanel.add(encoding8);
-//        encodingPanel.add(Box.createRigidArea(hpad20));
         encodingPanel.add(encoding9);
         encodingPanel.add(encoding10);
         encodingPanel.add(encoding11);
@@ -589,6 +600,32 @@ public class CDFConvert extends JFrame
         encodingPanel.add(encoding14);
         encodingPanel.add(encoding15);
 
+        // Initialize the epoch radio button.
+        EpochListener epochListener = new EpochListener();
+        epoch0.setActionCommand("");
+        epoch1.setActionCommand("epoch2tt2000");
+        epoch2.setActionCommand("tt20002epoch");
+        epoch3.setActionCommand("tt20002depoch");
+        epoch0.addActionListener(epochListener);
+        epoch1.addActionListener(epochListener);
+        epoch2.addActionListener(epochListener);
+        epoch3.addActionListener(epochListener);
+        epoch0.setSelected(true);
+        epoch.add(epoch0);
+        epoch.add(epoch1);
+        epoch.add(epoch2);
+        epoch.add(epoch3);
+        epoch0.setToolTipText("Keep the CDF epoch data type as is");
+        epoch1.setToolTipText("Convert the CDF epoch type from EPOCH/EPOCH16 to TT2000");
+        epoch2.setToolTipText("Convert the CDF epoch type from TT2000 to EPOCH");
+        epoch3.setToolTipText("Convert the CDF epoch type from TT2000 to EPOCH16");
+        epochPanel.setLayout(new GridLayout(1,8));
+        epochPanel.add(EPOCH);
+        epochPanel.add(epoch0);
+        epochPanel.add(epoch1);
+        epochPanel.add(epoch2);
+        epochPanel.add(epoch3);
+
 	makeJButton(panel2n, pgc, 0, 0, 1, 1, 1.0, 1.0);
         makeJButton(panel2n, ric, 1, 0, 1, 1, 1.0, 1.0);
         makeJButton(panel2n, dsc, 2, 0, 1, 1, 1.0, 1.0);
@@ -605,11 +642,10 @@ public class CDFConvert extends JFrame
         makeJButton(panel2n, tpanel2, 3, 1, 1, 1, 1.0, 1.0);
         makeJButton(panel2n, dpc, 0, 2, 1, 1, 1.0, 1.0);
         makeJButton(panel2n, rec, 1, 2, 1, 1, 1.0, 1.0);
-//        makeJButton(panel2n, bac, 2, 2, 1, 1, 1.0, 1.0);
         tpanel4.add(ZMODE,BorderLayout.WEST);
         tpanel4.add(zmodePanel, BorderLayout.CENTER);
         tpanel4.add(Box.createRigidArea(hpad20), BorderLayout.EAST);
-        makeJButton(panel2n, tpanel4, 3, 2, 1, 1, 1.0, 1.0);
+        makeJButton(panel2n, tpanel4, 2, 2, 1, 1, 1.0, 1.0);
         makeJButton(panel2n, dec, 0, 3, 1, 1, 1.0, 1.0);
 	int iijj = 1;
 	try {
@@ -627,10 +663,10 @@ public class CDFConvert extends JFrame
 	makeJButton(panel2n, tpanel5, iijj+1, 3, 1, 1, 1.0, 1.0);
 
 	panel2c.add(encodingPanel, BorderLayout.CENTER);
+        panel2c.add(epochPanel, BorderLayout.SOUTH);
 
         makeJButton(panel2s, SKLT, 0, 1, 1, 1, 1.0, 1.0);
         makeJButton(panel2s, sklt, 1, 1, 1, 1, 1.0, 1.0);
-//        makeJButton(panel2s, Box.createRigidArea(hpad10), 2, 1, 1, 1, 1.0, 1.0);
         makeJButton(panel2s, slt3, 2, 1, 1, 1, 1.0, 1.0);
         makeJButton(panel2s, CASS, 0, 2, 1, 1, 1.0, 1.0);
         makeJButton(panel2s, cachesizes, 1, 2, 2, 1, 1.0, 1.0);
@@ -664,6 +700,7 @@ public class CDFConvert extends JFrame
         zzc.setToolTipText("Select to convert -0.0 to 0.0");
         bkw.addItemListener(this);
         bkw.setToolTipText("Convert the file to a backward V2.7 version");
+
         abc.addItemListener(this);
         abc.setToolTipText("Display the current version");
 	bac.addItemListener(this);
@@ -841,6 +878,9 @@ public class CDFConvert extends JFrame
 		else 
 		  Encoding = "-encoding " + stren + " ";
 
+                if (strep.equals("")) Epoch = "";
+                else Epoch = "-" + strep;
+
                 strsp = sparseness.getText();
                 if (strsp.equals("") || strsp.trim().equals("")) Sparseness = " ";
                 else if (strsp.startsWith("\"") || strsp.startsWith("\'"))
@@ -882,7 +922,8 @@ public class CDFConvert extends JFrame
 			   cdfDelimiter + Zmode + strzz + fileDelimiter +  
 			   filespec + fileDelimiter + " " + Format + 
 			   Majority + Encoding + strde + Compression + 
-                           Sparseness + " " + strbw + " " + Checksum;
+                           Sparseness + " " + strbw + " " + Checksum + " " +
+                           stret + Epoch;
                 /*********************************
 		commandX = command + strpo + strds + strlp + skeleton + 
 			   " " + skeletonFile + " " +
@@ -904,7 +945,6 @@ public class CDFConvert extends JFrame
                     cmds[2] = commandX;
                 }
                 runit(cmds);
-                // runit(commandX);
 	} else if (obj == cdf1) {
 		cdfspec = cdf1.getText();
 	} else if (obj == cdf2) {
@@ -997,6 +1037,15 @@ public class CDFConvert extends JFrame
         }
     }
 
+/** Action for radio buttons for Epoch
+ */
+
+    class EpochListener implements ActionListener {
+        public void actionPerformed(ActionEvent e) {
+           strep = e.getActionCommand();
+        }
+    }
+
 /** Action for radio buttons for Checksum
  */
 
