@@ -177,8 +177,8 @@ public class CDFIRsDump extends JFrame
     }
 
     CDFIRsDump(JFrame parentFrame, String cdfbase, boolean modal) {
-        if (cdfbase != null) command = cdfbase + separator + "bin" + 
-				       separator + "cdfirsdump ";
+        if (cdfbase != null) command = "\"" + cdfbase + separator + "bin" + 
+				       separator + "cdfirsdump\" ";
         dialog = new JDialog(this, modal);
 	this.parentFrame = parentFrame;
         this.modal = modal;
