@@ -98,7 +98,7 @@ public class CDFMerge extends JFrame
 /** Labels for source/input CDFs. */
     JLabel CDF1 = new JLabel("Source 1 CDF: ");
     JLabel CDF2 = new JLabel("Source 2 CDF: ");
-    JLabel CDF3 = new JLabel("Source 3 CDF: ");
+    JLabel CDF3 = new JLabel("Source 3 CDF (optional): ");
 
 /** A label of "Destination CDF:" for the text field outfile. */
     JLabel DCDF = new JLabel("Output CDF: ");
@@ -218,8 +218,8 @@ public class CDFMerge extends JFrame
 
     CDFMerge(JFrame parentDriver, String cdfbase, boolean modal) {
 
-        if (cdfbase != null) command = cdfbase + separator + "bin" + 
-				       separator + "cdfmerge" ;
+        if (cdfbase != null) command = "\"" + cdfbase + separator + "bin" + 
+				       separator + "cdfmerge\" " ;
         dialog = new JDialog(this, modal);
         this.modal = modal;
 	this.parentDriver = parentDriver;
@@ -321,6 +321,10 @@ public class CDFMerge extends JFrame
         cdf2.addFocusListener(this);
         cdf2.addMouseListener(this);
         cdf2.setToolTipText("Enter the second source CDF (without extension)");
+        cdf3.addActionListener(this);
+        cdf3.addFocusListener(this);
+        cdf3.addMouseListener(this);
+        cdf3.setToolTipText("Enter the optional third source CDF (without extension)");
         outfile.addActionListener(this);
         outfile.addFocusListener(this);
         outfile.addMouseListener(this);
@@ -461,6 +465,7 @@ public class CDFMerge extends JFrame
         info.setText("");
 	cdf1.setText("");
 	cdf2.setText("");
+	cdf3.setText("");
 	outfile.setText("");
         inputfile.setText("");
         masterfile.setText("");
@@ -516,7 +521,6 @@ public class CDFMerge extends JFrame
                     cmds[1] = "-c";
                     cmds[2] = commandX;
                 }
-
                 runit(cmds);
 		hlp = 0;
 	} else if (obj == entrb) { // for "Enter" button
@@ -628,7 +632,6 @@ public class CDFMerge extends JFrame
                     cmds[1] = "-c";
                     cmds[2] = commandX;
                 }
-
                 runit(cmds);
 
 	// } else if (obj == cdf1) {
