@@ -67,7 +67,7 @@ public class CDFToolUtils implements CDFConstants {
 	      aInteger[i] = Integer.parseInt(((String)(vec.elementAt(i))).trim());
 	    return aInteger;
 	  }
-	} else if (dataType == CDF_UINT4) {
+	} else if (dataType == CDF_UINT4 || dataType == CDF_INT8) {
           if (filterElementsNum == 1) {
 	    long[] aLong = {Long.parseLong(data)};
 	    return aLong;
@@ -127,7 +127,7 @@ public class CDFToolUtils implements CDFConstants {
               double[] aDouble = new double[2];
               if (data.indexOf(":") == -1) { // not an EPOCH string
                 aDouble[0] = Double.valueOf(data).doubleValue();
-		aDouble[0] = 0.0;
+		aDouble[1] = 0.0;
 	      }
               else
                 aDouble = (double[]) Epoch16.parse((String)data);
@@ -149,9 +149,27 @@ public class CDFToolUtils implements CDFConstants {
               }
               return aDouble;
             }
-	  } catch (CDFException e) {
-	    System.err.println("error parsing Epoch16 ");
-	    return null;
+          } catch (CDFException f) {
+            System.err.println("error parsing Epoch ");
+            return null;
+          }           
+        } else if (dataType == CDF_TIME_TT2000) {
+          try {
+            if (filterElementsNum == 1) {
+              long[] aLong = new long[1];
+              aLong[0] = (long) CDFTT2000.fromUTCstring((String)data);
+              return aLong;
+            } else {
+              long[] aLong = new long[filterElementsNum];
+              for (int i = 0; i < filterElementsNum; i++) {
+                String ttt = ((String) vec.elementAt(i)).trim();
+		aLong[i] = (long) CDFTT2000.fromUTCstring(ttt);
+              }
+              return aLong;
+            }
+          } catch (CDFException g) { 
+            System.err.println("error parsing TT2000 string ");
+            return null;
 	  }
 	} 
 	return null;
@@ -178,7 +196,7 @@ public class CDFToolUtils implements CDFConstants {
         } else if (dataType == CDF_UINT2 || dataType == CDF_INT4) {
             Integer aInteger = new Integer(data);
             return aInteger;
-        } else if (dataType == CDF_UINT4) {
+        } else if (dataType == CDF_UINT4 || dataType == CDF_INT8) {
             Long aLong = new Long(data);
             return aLong;
         } else if (dataType == CDF_FLOAT || dataType == CDF_REAL4) {
@@ -203,7 +221,15 @@ public class CDFToolUtils implements CDFConstants {
             System.err.println("error parsing epoch16 ");
             return null;
           }
-	}
+        } else if (dataType == CDF_TIME_TT2000) {
+	  try {
+	    Long aLong = new Long(CDFTT2000.fromUTCstring(data));
+            return aLong;
+          } catch (CDFException e) {
+            System.err.println("error parsing TT2000 ");
+            return null;
+          }
+        }
         return null;
     }
 
@@ -221,6 +247,11 @@ public class CDFToolUtils implements CDFConstants {
   *  Breakdown the value(s) of the given data.  Data can be a java primitive
   *  data type, Java Object (non-array), or 1-dimensional array of
   *  primitive Java data type.
+  *  Valid values for argument which:
+  *  1 - CDF_EPOCH type
+  *  2 - CDF_EPOCH16 type
+  *  3 - CDF_TIME_TT2000 type
+  *  0 - all others
   *
   */
     public static String breakdownData (Object data, int which) {
@@ -234,31 +265,35 @@ public class CDFToolUtils implements CDFConstants {
         if (signature.charAt(0) == '[') {
             arrayLength = Array.getLength(data);
             for (i=0; i < arrayLength; i=i+jj) {
+                 if (i > 0) temp.append(",");
                  if (signature.charAt(1) == 'B')
-                     temp.append(Array.getByte(data,i)).append(",");
+                     temp.append(Array.getByte(data,i));
 
                  else if (signature.charAt(1) == 'S')
-                     temp.append(Array.getShort(data,i)).append(",");
+                     temp.append(Array.getShort(data,i));
 
                  else if (signature.charAt(1) == 'I')
-                     temp.append(Array.getInt(data,i)).append(",");
+                     temp.append(Array.getInt(data,i));
 
                  else if (signature.charAt(1) == 'J')
-                     temp.append(Array.getLong(data,i)).append(",");
+                     if (which == 0)
+                       temp.append(Array.getLong(data,i));
+                     else
+                       temp.append(CDFTT2000.toUTCstring(Array.getLong(data,i)));
 
                  else if (signature.charAt(1) == 'F')
-                     temp.append(Array.getFloat(data,i)).append(",");
+                     temp.append(Array.getFloat(data,i));
 
                  else if (signature.charAt(1) == 'D') {
 		     if (which == 1)
-		       temp.append(Epoch.encode(Array.getDouble(data,i))).append(",");
+		       temp.append(Epoch.encode(Array.getDouble(data,i)));
 		     else if (which == 2) {
 		       double[] mmm = new double[2];
 		       mmm[0] = Array.getDouble(data,2*i);
 		       mmm[1] = Array.getDouble(data,2*i+1);
-		       temp.append(Epoch16.encode(mmm)).append(",");
+		       temp.append(Epoch16.encode(mmm));
 		     } else
-                       temp.append(Array.getDouble(data,i)).append(",");
+                       temp.append(Array.getDouble(data,i));
 		}
             }
 	    temp.setLength(temp.length() - 1);
@@ -267,7 +302,9 @@ public class CDFToolUtils implements CDFConstants {
             temp.append(Epoch.encode(((Double)data).doubleValue()));
 	  else if (which == 2) 
 	    temp.append(Epoch16.encode((double[])data));
-	  else
+	  else if (which == 3)
+            temp.append(CDFTT2000.toUTCstring(((Long)data).longValue()));
+          else
 	    temp.append(data);
 	}
         return temp.toString();
@@ -594,16 +631,18 @@ public static int VariableWidth (int epoch, Variable var, long dataType,
       case 3: // EPOCH3_STYLE
         return 24;
       case 4: // EPOCHf_STYLE
-        break;                  /* Continue on... */
+        return 50;
       case 5: // EPOCHx_STYLE
-        return 30;
+        return 68;
+      case 6: // EPOCH4_STYLE
+        return 23;
     }
   }
   /****************************************************************************
   * Check for an EPOCH16 data type.  Depending on the style the format may be
   * ignored.
   ****************************************************************************/
-  if (dataType == CDF_EPOCH16) {
+  else if (dataType == CDF_EPOCH16) {
     switch (epoch) {
       case 0: // EPOCH0_STYLE_EXTEND
         return 36;
@@ -614,9 +653,23 @@ public static int VariableWidth (int epoch, Variable var, long dataType,
       case 3: // EPOCH3_STYLE_EXTEND
         return 36;
       case 4: // EPOCHf_STYLE_EXTEND
-        break;                  /* Continue on... */
+        return 50;
       case 5: // EPOCHx_STYLE_EXTEND
         return 50;
+      case 6: // EPOCH4_STYLE_EXTEND
+        return 32;
+    }
+  }
+  else if (dataType == CDF_TIME_TT2000) {
+    switch (epoch) {
+      case 0: // TT2000
+      case 1: 
+      case 2:
+      case 3:
+      case 4:
+      case 5:
+      case 6:
+        return 29;
     }
   }
   /****************************************************************************
@@ -650,6 +703,9 @@ public static int VariableWidth (int epoch, Variable var, long dataType,
     case (int)CDF_UINT4:
       width = 12; // = 10
       break;
+    case (int)CDF_INT8:
+      width = 20; // = 10
+      break;
     case (int)CDF_REAL4:
     case (int)CDF_FLOAT:
       width = 15;
@@ -659,11 +715,14 @@ public static int VariableWidth (int epoch, Variable var, long dataType,
       width = 18;
       break;
     case (int)CDF_EPOCH:     /* Format (C/Fortran) style. */
-      width = 12;
-      break;
-    case (int)CDF_EPOCH16:     /* Format (C/Fortran) style. */
       width = 24;
       break;
+    case (int)CDF_EPOCH16:   /* Format (C/Fortran) style. */
+      width = 36;
+      break;
+    case (int)CDF_TIME_TT2000: /* TT2000 type 3 style. */
+      width = 29;
+      break;
     default:            /* Unknown data type. */
       width = 0;
   }
@@ -732,6 +791,7 @@ public static int StandardWidth (int epoch, long dataType, long numElems) {
     case (int)CDF_INT2:
     case (int)CDF_UINT2:
     case (int)CDF_INT4:
+    case (int)CDF_INT8:
     case (int)CDF_UINT4:
     case (int)CDF_REAL4:
     case (int)CDF_FLOAT:
@@ -746,6 +806,7 @@ public static int StandardWidth (int epoch, long dataType, long numElems) {
         case 3: return 24;
         case 4: return 25;
         case 5: return 13;
+        case 6: return 23;
 	default: break;
       }
       break;
@@ -757,6 +818,16 @@ public static int StandardWidth (int epoch, long dataType, long numElems) {
         case 3: return 36;
         case 4: return 50;
         case 5: return 68;
+        case 6: return 32;
+	default: break;
+      }
+      break;
+    case (int)CDF_TIME_TT2000:
+      switch (epoch) {
+        case 0: return 30;
+        case 1: return 19;
+        case 2: return 14;
+        case 3: return 29;
 	default: break;
       }
       break;
@@ -780,6 +851,7 @@ public static String StandardFormat (int epoch, long dataType) {
     case (int)CDF_INT2: return new String("%6d");
     case (int)CDF_UINT2: return new String("%5u");
     case (int)CDF_INT4: return new String("%11ld");
+    case (int)CDF_INT8: return new String("%20ld");
     case (int)CDF_UINT4: return new String("%10ld");
     case (int)CDF_REAL4:
     case (int)CDF_FLOAT: return new String("%16.9e");
@@ -790,7 +862,8 @@ public static String StandardFormat (int epoch, long dataType) {
         case 0:
         case 1:
         case 2:
-        case 3: return null;
+        case 3:
+        case 6: return null;
         case 4: return new String("%25.17e");
         case 5: return new String("*Unsupported*");
 	default: break;
@@ -801,12 +874,25 @@ public static String StandardFormat (int epoch, long dataType) {
         case 0:
         case 1:
         case 2:
-        case 3: return null;
+        case 3:
+        case 6: return null;
         case 4: return new String("%25.17e %25.17e");
         case 5: return new String("*Unsupported*");
 	default: break;
       }
       break;
+    case (int)CDF_TIME_TT2000:
+      switch (epoch) {
+        case 0:
+        case 1:
+        case 2:
+        case 3:
+        case 4:
+        case 5:
+        case 6: return new String("%20ld");
+	default: break;
+      }
+      break;
     default: break;
   }
   return null;
@@ -1010,6 +1096,15 @@ public static StringBuffer Justify (StringBuffer string, int minWidth) {
             default:
               return false;
           }
+        case (int)CDF_INT8:
+        case (int)CDF_TIME_TT2000:
+          switch ((int)dataType2) {
+            case (int)CDF_INT8:
+            case (int)CDF_TIME_TT2000:
+              return true;
+            default:
+              return false;
+          }
         case (int)CDF_REAL4:
         case (int)CDF_FLOAT:
           switch ((int)dataType2) {
