@@ -24,8 +24,8 @@ public class CDFToolsDriver extends JFrame implements ActionListener {
 /** The file separator. */
     String separator = System.getProperty("file.separator");
     String osName = System.getProperty("os.name");
-    JRadioButton rb1, rb2, rb3, rb4, rb5, rb6, rb7, rb8, rb9, rba, rbb, rbc, qut, 
-                 non;
+    JRadioButton rb1, rb2, rb3, rb4, rb5, rb6, rb7, rb8, rb9, rba, rbb, rbc,
+                 rbd, qut, non;
 /** The default file name at which the CDF logo file is located. */
 //    String basegif = cdfbase + separator + "java" + separator + "cdf_banner.jpg";
 /** The alternated file name for CDF logo if it is not at the default directory. */
@@ -58,6 +58,8 @@ public class CDFToolsDriver extends JFrame implements ActionListener {
     String cdfmerge = "CDFMerge";
 /** The action command for selecting the CDFValidate radiobutton. */
     String cdfvalidate = "CDFValidate";
+/** The action command for selecting the CDFLeapSecondsInfo radiobutton. */
+    String cdfleapsecondsinfo = "CDFLeapSecondsInfo";
 /** The action command for selecting the CDFEdit radiobutton. */
     String cdfedit = "CDFEdit";
 /** The action command for selecting the CDFExport radiobutton. */
@@ -84,7 +86,8 @@ public class CDFToolsDriver extends JFrame implements ActionListener {
 //  each tool program will run as an independent thread
     Thread threadinquire, threadstats, threadcompare, threadconvert,
            threadskeletontable, threadskeletoncdf, threaddump, threaddir,
-           threadmerge, threadvalidate, threadedit, threadexport;
+           threadmerge, threadvalidate, threadleapseconds, threadedit,
+           threadexport;
 
 //  Each tool as an object from its class 
 /** A CDFInquire object is initiated when it is selected to run.*/ 
@@ -99,6 +102,8 @@ public class CDFToolsDriver extends JFrame implements ActionListener {
     CDFDump pgmdump = null;
 /** A CDFDir object is initiated when it is selected to run.*/
     CDFDir pgmdir = null;
+/** A CDFLeapSecondsInfo object is initiated when it is selected to run.*/
+    CDFLeapSecondsInfo pgmleapseconds = null;
 /** A CDFMerge object is initiated when it is selected to run.*/
     CDFMerge pgmmerge = null;
 /** A CDFValidate object is initiated when it is selected to run.*/
@@ -247,7 +252,7 @@ public class CDFToolsDriver extends JFrame implements ActionListener {
 	panel1.setBorder(new TitledBorder(new EtchedBorder(), "Select a tool to run"));
 
 	rb1 = new JRadioButton("SkeletonTable");
-	rb1.setMnemonic('1');
+//	rb1.setMnemonic('1');
 	rb1.setToolTipText("<html><center>"+
 			   "Run the command-line based SkeletonTable Tool Program."+
 			   "<br>"+
@@ -258,7 +263,7 @@ public class CDFToolsDriver extends JFrame implements ActionListener {
 	buttonGroup.add(rb1);
 
 	rb2 = new JRadioButton("SkeletonCDF");
-	rb2.setMnemonic('2');
+//	rb2.setMnemonic('2');
 	rb2.setToolTipText("<html><center>"+
                            "Run the command-line based SkeletonCDF Tool Program."+
                            "<br>"+
@@ -269,7 +274,7 @@ public class CDFToolsDriver extends JFrame implements ActionListener {
 	buttonGroup.add(rb2);
 
 	rb3 = new JRadioButton("CDFConvert");
-	rb3.setMnemonic('3');
+//	rb3.setMnemonic('3');
 	rb3.setToolTipText("<html><center>"+
                            "Run the command-line based CDFConvert Tool Program."+
                            "<br>"+
@@ -280,7 +285,7 @@ public class CDFToolsDriver extends JFrame implements ActionListener {
 	buttonGroup.add(rb3);
 
 	rb4 = new JRadioButton("CDFCompare");
-	rb4.setMnemonic('4');
+//	rb4.setMnemonic('4');
 	rb4.setToolTipText("<html><center>"+
                            "Run the command-line based CDFCompare Tool Program."+
                            "<br>"+
@@ -291,7 +296,7 @@ public class CDFToolsDriver extends JFrame implements ActionListener {
 	buttonGroup.add(rb4);
 
 	rb5 = new JRadioButton("CDFInquire");
-	rb5.setMnemonic('5');
+//	rb5.setMnemonic('5');
 	rb5.setToolTipText("<html><center>"+
                            "Run the command-line based CDFInquire Tool Program."+
                            "<br>"+
@@ -302,7 +307,7 @@ public class CDFToolsDriver extends JFrame implements ActionListener {
 	buttonGroup.add(rb5);
 
         rb6 = new JRadioButton("CDFStats");
-        rb6.setMnemonic('6');
+//      rb6.setMnemonic('6');
         rb6.setToolTipText("<html><center>"+
                            "Run the command-line based CDFStats Tool Program."+
                            "<br>"+
@@ -313,7 +318,7 @@ public class CDFToolsDriver extends JFrame implements ActionListener {
         buttonGroup.add(rb6);
 
         rb7 = new JRadioButton("CDFDump");
-        rb7.setMnemonic('7');
+//      rb7.setMnemonic('7');
         rb7.setToolTipText("<html><center>"+
                            "Run the command-line based CDFDump Tool Program."+
                            "<br>"+
@@ -324,7 +329,7 @@ public class CDFToolsDriver extends JFrame implements ActionListener {
         buttonGroup.add(rb7);
 
         rb8 = new JRadioButton("CDFDir");
-        rb8.setMnemonic('8');
+//      rb8.setMnemonic('8');
         rb8.setToolTipText("<html><center>"+
                            "Run the command-line based CDFDir Tool Program."+
                            "<br>"+
@@ -335,7 +340,7 @@ public class CDFToolsDriver extends JFrame implements ActionListener {
         buttonGroup.add(rb8);
 
         rbb = new JRadioButton("CDFMerge");
-        rbb.setMnemonic('b');
+//      rbb.setMnemonic('b');
         rbb.setToolTipText("<html><center>"+
                            "Run the command-line based CDFMerge Tool Program."+
                            "<br>"+
@@ -346,7 +351,7 @@ public class CDFToolsDriver extends JFrame implements ActionListener {
         buttonGroup.add(rbb);
 
         rbc = new JRadioButton("CDFValidate");
-        rbc.setMnemonic('c');
+//      rbc.setMnemonic('c');
         rbc.setToolTipText("<html><center>"+
                            "Run the command-line based CDFValidate Tool Program."+
                            "<br>"+
@@ -356,15 +361,26 @@ public class CDFToolsDriver extends JFrame implements ActionListener {
         rbc.addActionListener(this);
         buttonGroup.add(rbc);
 
+        rbd = new JRadioButton("CDFLeapSecondsInfo");
+//      rbd.setMnemonic('d');
+        rbd.setToolTipText("<html><center>"+
+                           "Run the command-line based CDFLeapSecondsInfo Tool Program."+
+                           "<br>"+
+                           "Need to define CDF_BASE environment variable."+
+                           "</center></html>");
+        rbd.setActionCommand(cdfleapsecondsinfo);
+        rbd.addActionListener(this);
+        buttonGroup.add(rbd);
+
         rb9 = new JRadioButton("CDFEdit");
-        rb9.setMnemonic('9');
+//      rb9.setMnemonic('9');
         rb9.setToolTipText("Run the CDFEdit Tool Program");
         rb9.setActionCommand(cdfedit);
         rb9.addActionListener(this);
         buttonGroup.add(rb9);
 
         rba = new JRadioButton("CDFExport");
-        rba.setMnemonic('a');
+//      rba.setMnemonic('a');
         rba.setToolTipText("Run the CDFExport Tool Program");
         rba.setActionCommand(cdfexport);
         rba.addActionListener(this);
@@ -389,6 +405,7 @@ public class CDFToolsDriver extends JFrame implements ActionListener {
         panel1.add(rb8);
         panel1.add(rbb);
 	panel1.add(rbc);
+	panel1.add(rbd);
 	panel1.add(rb9);
 	panel1.add(rba);
 	panel1.add(Box.createRigidArea(vpad5));
@@ -595,6 +612,22 @@ public class CDFToolsDriver extends JFrame implements ActionListener {
             }
           }
           new ResetButton().start();
+        } else if (pgm.equals("CDFLeapSecondsInfo")) {
+          if (osName.toLowerCase().indexOf("windows") == -1 && cdfbase == null) {
+            tf.setText("CDF_BASE environment variable has not been defined...");
+            Toolkit.getDefaultToolkit().beep();
+          } else {
+            if (threadleapseconds == null) {
+              tf.setText("Loading...");
+              new ClearInfo(tf).start();
+              pgmleapseconds = new CDFLeapSecondsInfo(theDriver.getFrame(), cdfbase);
+              threadleapseconds = new Thread(pgmleapseconds);
+              threadleapseconds.start();
+            } else {
+              pgmleapseconds.reEnter();
+            }
+          }
+          new ResetButton().start();
 	} else if (pgm.equals("CDFEdit")) {
           if (threadedit == null) {
 	    tf.setText("Loading...");
