@@ -1,4 +1,4 @@
-// $Id: EditAttrEntryPanel.java,v 1.1.1.1 2010/01/13 20:06:14 liu Exp $
+// $Id: EditAttrEntryPanel.java,v 1.3 2012/06/27 18:34:45 liu Exp $
 
 // Swing Imports
 import javax.swing.*;
@@ -318,14 +318,16 @@ public class EditAttrEntryPanel extends JDialog
 	
 	if (selectedAttr != null)
 	  if (scope == GLOBAL_SCOPE) {
-	    for (Enumeration e = selectedAttr.getEntries().elements() ; 
-		 e.hasMoreElements() ; ) {
+            try {
+              Enumeration e = selectedAttr.getEntries().elements();
+  	      for (; e.hasMoreElements() ; ) {
 		Entry en = (Entry) e.nextElement();
 		if (en != null) {
           	  String nEntry = "" + (en.getID()+1);
 		  v.addElement(nEntry);
 		}
-	    }
+	      }
+	    } catch (CDFException ex) { }
 	  } else {
             for (Enumeration e = myEditor.theCDF.getVariables().elements() ;
                  e.hasMoreElements() ; ) {
