@@ -1,4 +1,4 @@
-// $Id: EditVariableDialog.java,v 1.1.1.1 2010/01/13 20:06:14 liu Exp $
+// $Id: EditVariableDialog.java,v 1.1 2012/05/18 17:44:27 liu Exp $
 
 import javax.swing.*;
 import javax.swing.border.*;
@@ -109,7 +109,7 @@ public class EditVariableDialog extends JDialog implements ActionListener, CDFCo
 	gbc.anchor = GridBagConstraints.NORTHWEST;
 	gbc.insets = new Insets(2,2,2,2);
 
-	Vector types = new Vector(15);
+	Vector types = new Vector(17);
 	types.addElement("CDF_BYTE");
 	types.addElement("CDF_INT1");
 	types.addElement("CDF_UINT1");
@@ -117,12 +117,14 @@ public class EditVariableDialog extends JDialog implements ActionListener, CDFCo
 	types.addElement("CDF_UINT2");
 	types.addElement("CDF_INT4");
 	types.addElement("CDF_UINT4");
+	types.addElement("CDF_INT8");
 	types.addElement("CDF_REAL4");
 	types.addElement("CDF_FLOAT");
 	types.addElement("CDF_REAL8");
 	types.addElement("CDF_DOUBLE");
 	types.addElement("CDF_EPOCH");
 	types.addElement("CDF_EPOCH16");
+	types.addElement("CDF_TIME_TT2000");
 	types.addElement("CDF_CHAR");
 	types.addElement("CDF_UCHAR");
 
@@ -469,14 +471,16 @@ public class EditVariableDialog extends JDialog implements ActionListener, CDFCo
 		    case 4:  dt = CDF_UINT2;  break;
 		    case 5:  dt = CDF_INT4;   break;
 		    case 6:  dt = CDF_UINT4;  break;
-		    case 7:  dt = CDF_REAL4;  break;
-		    case 8:  dt = CDF_FLOAT;  break;
-		    case 9:  dt = CDF_REAL8;  break;
-		    case 10: dt = CDF_DOUBLE; break;
-		    case 11: dt = CDF_EPOCH;  break;
-		    case 12: dt = CDF_EPOCH16;  break;
-		    case 13: dt = CDF_CHAR;   break;
-		    case 14: dt = CDF_UCHAR;  break;
+		    case 7:  dt = CDF_INT8;  break;
+		    case 8:  dt = CDF_REAL4;  break;
+		    case 9:  dt = CDF_FLOAT;  break;
+		    case 10:  dt = CDF_REAL8;  break;
+		    case 11: dt = CDF_DOUBLE; break;
+		    case 12: dt = CDF_EPOCH;  break;
+		    case 13: dt = CDF_EPOCH16;  break;
+		    case 14: dt = CDF_TIME_TT2000;  break;
+		    case 15: dt = CDF_CHAR;   break;
+		    case 16: dt = CDF_UCHAR;  break;
 		    // keep compiler happy
 		    default: dt = CDF_BYTE;   break;
 		  }
@@ -858,16 +862,22 @@ public class EditVariableDialog extends JDialog implements ActionListener, CDFCo
         if (pad == null)
           padString = "";
         else {
-          if (dataType != CDF_EPOCH && dataType != CDF_EPOCH16)
+          if (dataType != CDF_EPOCH && dataType != CDF_EPOCH16 &&
+              dataType != CDF_TIME_TT2000)
             padString = pad.toString();
           else {
-	    if (dataType != CDF_EPOCH) {
+	    if (dataType == CDF_EPOCH16) {
 	      double[] aaa = new double[2];
 	      aaa[0] = ((Double)pad).doubleValue();
 	      aaa[1] = ((Double)pad).doubleValue();
               padString = Epoch16.encode(aaa);
-	    } else
-	      padString = Epoch.encode(((Double)pad).doubleValue());
+	    } else if (dataType == CDF_EPOCH) {
+              double aaa = ((Double)pad).doubleValue();
+              padString = Epoch.encode(aaa);
+            } else {
+              long aaa = ((Long)pad).longValue();
+	      padString = CDFTT2000.toUTCstring(aaa);
+            }
 	  }
         }
         tfpv.setText(padString);
