@@ -96,12 +96,14 @@ public class EditgAttributeTableScrollPane extends JScrollPane implements CDFCon
         comboBox.addItem("CDF_UINT2");
         comboBox.addItem("CDF_INT4");
         comboBox.addItem("CDF_UINT4");
+        comboBox.addItem("CDF_INT8");
         comboBox.addItem("CDF_REAL4");
         comboBox.addItem("CDF_FLOAT");
         comboBox.addItem("CDF_REAL8");
         comboBox.addItem("CDF_DOUBLE");
         comboBox.addItem("CDF_EPOCH");
 	comboBox.addItem("CDF_EPOCH16");
+	comboBox.addItem("CDF_TIME_TT2000");
         comboBox.addItem("CDF_CHAR");
         comboBox.addItem("CDF_UCHAR");
 
@@ -326,12 +328,23 @@ public class EditgAttributeTableScrollPane extends JScrollPane implements CDFCon
                 formatter.setParseIntegerOnly(true);
                 try {
                   if (newone instanceof Integer)
-                    return new Long(formatter.parse(((Integer)newone).toString()).intValue());
+                    return new Integer(formatter.parse(((Integer)newone).toString()).intValue());
                   else
                     return (String) "" + formatter.parse((String)newone).intValue();
                 } catch (ParseException e) {
                   return null;
                 }
+            } else if (dataType.equals("CDF_UINT4") || dataType.equals("CDF_INT8")) {
+
+                formatter.setParseIntegerOnly(true);
+                try {
+                  if (newone instanceof Long)
+                    return new Long(formatter.parse(((Long)newone).toString()).longValue());
+                  else
+                    return (String) "" + formatter.parse((String)newone).longValue();
+                } catch (ParseException e) {
+                  return null;
+                }
             } else if (dataType.equals("CDF_REAL4") || dataType.equals("CDF_FLOAT")) {
                 formatter.setParseIntegerOnly(false);
                 try {
@@ -400,59 +413,71 @@ public class EditgAttributeTableScrollPane extends JScrollPane implements CDFCon
 	    if (attr.getScope() == GLOBAL_SCOPE) {
 
               attrName = attr.getName();
-
-	      Vector entries = attr.getEntries();
-	      if (entries.size() == 0) { // no entries yet
-	      } else {
-		if (ii == totalEntries) break;
-	        dataObject[ii][0] = attrName;
-	        for (Enumeration e1 = entries.elements(); e1.hasMoreElements(); ) {
-	  	  en = (Entry) e1.nextElement();
-		  if (en == null) continue;
-		  id = en.getID();
-		  dataType = en.getDataType();
-		  value = en.getData();
-		  long length = en.getNumElements();
-		  dataObject[ii][1] = "" + (id + 1);
-		  dataObject[ii][2] = CDFUtils.getStringDataType(dataType) + "/" +
+              	
+	      Vector entries;
+              try {
+                entries = attr.getEntries();
+	        if (entries.size() == 0) { // no entries yet
+	        } else {
+		  if (ii == totalEntries) break;
+	          dataObject[ii][0] = attrName;
+	          for (Enumeration e1 = entries.elements(); e1.hasMoreElements(); ) {
+	  	    en = (Entry) e1.nextElement();
+		    if (en == null) continue;
+		    id = en.getID();
+		    dataType = en.getDataType();
+		    value = en.getData();
+		    long length = en.getNumElements();
+		    dataObject[ii][1] = "" + (id + 1);
+		    dataObject[ii][2] = CDFUtils.getStringDataType(dataType) + "/" +
 					length;
-                  if (dataType == CDF_EPOCH) {
-		    if (value.getClass().getName().indexOf('[') == 0) { // an array
-		      StringBuffer tmpStr = new StringBuffer();
-		      for (int i = 0; i < ((double[])value).length; i++) {
-			String tmp = Epoch.encode(((double[])value)[i]);
-			tmpStr.append(tmp).append(", ");
-		      }
-		      tmpStr.setLength(tmpStr.length()-2);
-		      dataObject[ii][3] = tmpStr.toString();
-		    } else 
-		      dataObject[ii][3] = Epoch.encode(((Double)value).doubleValue());
-                  } else if (dataType == CDF_EPOCH16) {
-                    if (value.getClass().getName().indexOf('[') == 0) { // an array
-                      StringBuffer tmpStr = new StringBuffer();
-		      double[] mmm = new double[2];
-                      for (int i = 0; i < ((double[])value).length; i=i+2) {
-			mmm[0] = ((double[])value)[i];
-			mmm[1] = ((double[])value)[i+1];
-                        String tmp = Epoch16.encode(mmm);
-                        tmpStr.append(tmp).append(", ");
-                      }
-                      tmpStr.setLength(tmpStr.length()-2);
-                      dataObject[ii][3] = tmpStr.toString();
-                    } 
-                  } else 
-		    dataObject[ii][3] = CDFUtils.getStringData(value, ", ");
-		  ii++;
-		}
-	      }
-	    }
-
+                    if (dataType == CDF_EPOCH) {
+		      if (value.getClass().getName().indexOf('[') == 0) { // an array
+		        StringBuffer tmpStr = new StringBuffer();
+		        for (int i = 0; i < ((double[])value).length; i++) {
+                          if (i > 0) tmpStr.append(", ");
+			  String tmp = Epoch.encode(((double[])value)[i]);
+			  tmpStr.append(tmp);
+		        }
+		        dataObject[ii][3] = tmpStr.toString();
+		      } else 
+		        dataObject[ii][3] = Epoch.encode(((Double)value).doubleValue());
+                    } else if (dataType == CDF_EPOCH16) {
+                      if (value.getClass().getName().indexOf('[') == 0) { // an array
+                        StringBuffer tmpStr = new StringBuffer();
+		        double[] mmm = new double[2];
+                        for (int i = 0; i < ((double[])value).length; i=i+2) {
+                          if (i > 0) tmpStr.append(", ");
+			  mmm[0] = ((double[])value)[i];
+			  mmm[1] = ((double[])value)[i+1];
+                          String tmp = Epoch16.encode(mmm);
+                          tmpStr.append(tmp);
+                        }
+                        dataObject[ii][3] = tmpStr.toString();
+                      } 
+                    } else if (dataType == CDF_TIME_TT2000) {
+                      if (value.getClass().getName().indexOf('[') == 0) { // an array
+                        StringBuffer tmpStr = new StringBuffer();
+                        for (int i = 0; i < ((long[])value).length; i++) {
+                          if (i > 0) tmpStr.append(", ");
+                          String tmp = CDFTT2000.toUTCstring(((long[])value)[i]);
+                          tmpStr.append(tmp);
+                        }
+                        dataObject[ii][3] = tmpStr.toString();
+                      } else
+                        dataObject[ii][3] = CDFTT2000.toUTCstring(((Long)value).longValue());
+                    } else 
+		      dataObject[ii][3] = CDFUtils.getStringData(value, ", ");
+		    ii++;
+		  }
+	        }
+	      } catch (CDFException ex) { }
+            }
         }
 	table = null;
         if (dataObject != null) {
           myModel = new MyTableModel();
           table = new JTable(myModel);
-//          myModel.addTableModelListener(this);
           table.setRowSelectionAllowed(false);
           table.sizeColumnsToFit(JTable.AUTO_RESIZE_ALL_COLUMNS);
 
