@@ -116,12 +116,14 @@ public class EditgEntryTablePanel extends JPanel implements CDFConstants {
         comboBox.addItem("CDF_UINT2");
         comboBox.addItem("CDF_INT4");
         comboBox.addItem("CDF_UINT4");
+        comboBox.addItem("CDF_INT8");
         comboBox.addItem("CDF_REAL4");
         comboBox.addItem("CDF_FLOAT");
         comboBox.addItem("CDF_REAL8");
         comboBox.addItem("CDF_DOUBLE");
         comboBox.addItem("CDF_EPOCH");
 	comboBox.addItem("CDF_EPOCH16");
+	comboBox.addItem("CDF_TIME_TT2000");
         comboBox.addItem("CDF_CHAR");
         comboBox.addItem("CDF_UCHAR");
 
@@ -344,12 +346,23 @@ public class EditgEntryTablePanel extends JPanel implements CDFConstants {
                 formatter.setParseIntegerOnly(true);
                 try {
                   if (newone instanceof Integer)
-                    return new Long(formatter.parse(((Integer)newone).toString()).intValue());
+                    return new Integer(formatter.parse(((Integer)newone).toString()).intValue());
                   else
                     return (String) "" + formatter.parse((String)newone).intValue();
                 } catch (ParseException e) {
                   return null;
                 }
+            } else if (dataType.equals("CDF_UINT4") || dataType.equals("CDF_INT8")) {
+
+                formatter.setParseIntegerOnly(true);
+                try {
+                  if (newone instanceof Long)
+                    return new Long(formatter.parse(((Long)newone).toString()).longValue());
+                  else
+                    return (String) "" + formatter.parse((String)newone).longValue();
+                } catch (ParseException e) {
+                  return null;
+                }
             } else if (dataType.equals("CDF_REAL4") || dataType.equals("CDF_FLOAT")) {
                 formatter.setParseIntegerOnly(false);
                 try {
@@ -391,8 +404,11 @@ public class EditgEntryTablePanel extends JPanel implements CDFConstants {
 
     private void buildDataTable() {
 
-        Vector entries = selectedAttr.getEntries();
-
+        Vector entries;
+        try {
+          entries = selectedAttr.getEntries();
+        } catch (CDFException ex) { entries = null;}
+        
 	dataObject = null;
 
 	if (entries != null) {
@@ -430,10 +446,11 @@ public class EditgEntryTablePanel extends JPanel implements CDFConstants {
                   if (value.getClass().getName().indexOf('[') == 0) { // an array
                     StringBuffer tmpStr = new StringBuffer();
                     for (int i = 0; i < ((double[])value).length; i++) {
+                      if (i > 0) tmpStr.append(", ");
                       String tmp = Epoch.encode(((double[])value)[i]);
-                      tmpStr.append(tmp).append(", ");
+                      tmpStr.append(tmp);
                     }
-                    tmpStr.setLength(tmpStr.length()-2);
+//                    tmpStr.setLength(tmpStr.length()-2);
                     dataObject[jj][2] = tmpStr.toString();
                   } else
 	      	    dataObject[jj][2] = Epoch.encode(((Double)value).doubleValue());
@@ -441,15 +458,28 @@ public class EditgEntryTablePanel extends JPanel implements CDFConstants {
                   if (value.getClass().getName().indexOf('[') == 0) { // an array
                     StringBuffer tmpStr = new StringBuffer();
                     for (int i = 0; i < ((double[])value).length; i=i+2) {
+                      if (i > 0) tmpStr.append(", ");
 		      double[] aaa = new double[2];
 		      aaa[0] = ((double[])value)[i];
 		      aaa[1] = ((double[])value)[i+1];
                       String tmp = Epoch16.encode(aaa);
-                      tmpStr.append(tmp).append(", ");
+                      tmpStr.append(tmp);
                     }
-                    tmpStr.setLength(tmpStr.length()-2);
+//                    tmpStr.setLength(tmpStr.length()-2);
                     dataObject[jj][2] = tmpStr.toString();
                   } 
+		} else if (dataType == CDF_TIME_TT2000) {
+                  if (value.getClass().getName().indexOf('[') == 0) { // an array
+                    StringBuffer tmpStr = new StringBuffer();
+                    for (int i = 0; i < ((long[])value).length; i++) {
+                      if (i > 0) tmpStr.append(", ");
+                      String tmp = CDFTT2000.toUTCstring(((long[])value)[i]);
+                      tmpStr.append(tmp);
+                    }
+//                    tmpStr.setLength(tmpStr.length()-2);
+                    dataObject[jj][2] = tmpStr.toString();
+                  } else
+	      	    dataObject[jj][2] = CDFTT2000.toUTCstring(((Long)value).longValue());
                 } else 
 		    dataObject[jj][2] = CDFUtils.getStringData(value, ",");
 	    }
