@@ -135,12 +135,14 @@ public class EditvAttributeTableScrollPane extends JScrollPane implements TableM
         comboBox.addItem("CDF_UINT2");
         comboBox.addItem("CDF_INT4");
         comboBox.addItem("CDF_UINT4");
+        comboBox.addItem("CDF_INT8");
         comboBox.addItem("CDF_REAL4");
         comboBox.addItem("CDF_FLOAT");
         comboBox.addItem("CDF_REAL8");
         comboBox.addItem("CDF_DOUBLE");
         comboBox.addItem("CDF_EPOCH");
 	comboBox.addItem("CDF_EPOCH16");
+	comboBox.addItem("CDF_TIME_TT2000");
         comboBox.addItem("CDF_CHAR");
         comboBox.addItem("CDF_UCHAR");
 
@@ -363,12 +365,23 @@ public class EditvAttributeTableScrollPane extends JScrollPane implements TableM
                 formatter.setParseIntegerOnly(true);
                 try {
                   if (newone instanceof Integer)
-                    return new Long(formatter.parse(((Integer)newone).toString()).intValue());
+                    return new Integer(formatter.parse(((Integer)newone).toString()).intValue());
                   else
                     return (String) "" + formatter.parse((String)newone).intValue();
                 } catch (ParseException e) {
                   return null;
                 }
+            } else if (dataType.equals("CDF_UINT4") || dataType.equals("CDF_INT8")) {
+
+                formatter.setParseIntegerOnly(true);
+                try {
+                  if (newone instanceof Long)
+                    return new Long(formatter.parse(((Long)newone).toString()).longValue());
+                  else
+                    return (String) "" + formatter.parse((String)newone).longValue();
+                } catch (ParseException e) {
+                  return null;
+                }
             } else if (dataType.equals("CDF_REAL4") || dataType.equals("CDF_FLOAT")) {
                 formatter.setParseIntegerOnly(false);
                 try {
@@ -439,10 +452,11 @@ public class EditvAttributeTableScrollPane extends JScrollPane implements TableM
                     if (value.getClass().getName().indexOf('[') == 0) { // an array
                       StringBuffer tmpStr = new StringBuffer();
                       for (int i = 0; i < ((double[])value).length; i++) {
+                        if (i > 0) tmpStr.append(", ");
                         String tmp = Epoch.encode(((double[])value)[i]);
-                        tmpStr.append(tmp).append(", ");
+                        tmpStr.append(tmp);
                       }
-                      tmpStr.setLength(tmpStr.length()-2);
+//                      tmpStr.setLength(tmpStr.length()-2);
                       dataObject[jj][2] = tmpStr.toString();
                     } else
                       dataObject[jj][2] = Epoch.encode(((Double)value).doubleValue());
@@ -451,14 +465,27 @@ public class EditvAttributeTableScrollPane extends JScrollPane implements TableM
                       StringBuffer tmpStr = new StringBuffer();
 		      double[] mmm =new double[2];
                       for (int i = 0; i < ((double[])value).length; i=i+2) {
+                        if (i > 0) tmpStr.append(", ");
 			mmm[0] = ((double[])value)[i];
 			mmm[1] = ((double[])value)[i+1];
                         String tmp = Epoch16.encode(mmm);
-                        tmpStr.append(tmp).append(", ");
+                        tmpStr.append(tmp);
                       }
-                      tmpStr.setLength(tmpStr.length()-2);
+//                      tmpStr.setLength(tmpStr.length()-2);
                       dataObject[jj][2] = tmpStr.toString();
                     } 
+                  } else if (dataType == CDF_TIME_TT2000) {
+                    if (value.getClass().getName().indexOf('[') == 0) { // an array
+                      StringBuffer tmpStr = new StringBuffer();
+                      for (int i = 0; i < ((long[])value).length; i++) {
+                        if (i > 0) tmpStr.append(", ");
+                        String tmp = CDFTT2000.toUTCstring(((long[])value)[i]);
+                        tmpStr.append(tmp);
+                      }
+//                      tmpStr.setLength(tmpStr.length()-2);
+                      dataObject[jj][2] = tmpStr.toString();
+                    } else
+                      dataObject[jj][2] = CDFTT2000.toUTCstring(((Long)value).longValue());
                   } else
 	             dataObject[jj][2] = CDFUtils.getStringData(value, ", ");
 		} catch (CDFException ex) { System.out.println("error..."+ex);}
