@@ -417,18 +417,23 @@ public class ExportCDFTable extends JDialog implements CDFConstants {
 	int ii = 0;
 	String varName = null;
 	Variable v = null;
+        int style;
         for (Enumeration e = myCDFExport.vars.elements(); e.hasMoreElements(); ii++) {
 
             v = (Variable) e.nextElement();
             varName = v.getName();
-
+            long dataType = v.getDataType();
+            if (dataType == CDF_TIME_TT2000) style = 3;
+            else if (dataType == CDF_EPOCH) style = 1;
+            else if (dataType == CDF_EPOCH16) style = 2;
+            else style = 0;
 	    i = 1;
 	    filterObject[istart+ii][0] = varName;
 
 	    if (myCDFExport.getValidMin() == 1) {
 	      try { 
 	        Object validMin = v.getEntryData("VALIDMIN");
-	        String tmp = CDFToolUtils.breakdownData(validMin);
+	        String tmp = CDFToolUtils.breakdownData(validMin, style);
                 filterObject[istart+ii][i] = tmp;
 	        filterInitialObject[istart+ii][i++] = tmp;
 	      } catch (CDFException ex) {
@@ -440,7 +445,7 @@ public class ExportCDFTable extends JDialog implements CDFConstants {
 	    if (myCDFExport.getValidMax() == 1) {
               try {  
                 Object validMax = v.getEntryData("VALIDMAX");
-	        String tmp = CDFToolUtils.breakdownData(validMax);
+	        String tmp = CDFToolUtils.breakdownData(validMax, style);
                 filterObject[istart+ii][i] = tmp;
 	        filterInitialObject[istart+ii][i++] = tmp;
               } catch (CDFException ex) {
@@ -452,7 +457,7 @@ public class ExportCDFTable extends JDialog implements CDFConstants {
 	    if (myCDFExport.getFillVal() == 1) {
               try {  
                 Object fillVal = v.getEntryData("FILLVAL");
-	        String tmp = CDFToolUtils.breakdownData(fillVal);
+	        String tmp = CDFToolUtils.breakdownData(fillVal, style);
                 filterObject[istart+ii][i] = tmp;
 	        filterInitialObject[istart+ii][i] = tmp;
               } catch (CDFException ex) {
