@@ -534,7 +534,8 @@ public class ExportCreateCDF implements CDFConstants, Runnable {
                           else _dataArray = new Integer(0);
                         }
                     }
-		} else if (dataType == CDF_UINT4) {
+		} else if (dataType == CDF_UINT4 || dataType == CDF_INT8 ||
+                           dataType == CDF_TIME_TT2000) {
                     long along = ((Long)_dataArray).longValue();
                     long afill = 0L;
                     long amax = 0L;
@@ -548,7 +549,6 @@ public class ExportCreateCDF implements CDFConstants, Runnable {
                       if (amin < 0) amin -= (long) 2*Integer.MIN_VALUE;
                       if (amax < 0) amax -= (long) 2*Integer.MIN_VALUE;
                     }
-
                     if (minObj != null) {
                         if (along < amin) {
                           goon = false;
@@ -780,20 +780,23 @@ public class ExportCreateCDF implements CDFConstants, Runnable {
                             }
                         }
                     }
-		} else if (dataType == CDF_UINT4) {
+		} else if (dataType == CDF_UINT4 || dataType == CDF_INT8 ||
+                           dataType == CDF_TIME_TT2000) {
                     long along = 0;
                     long tmpMin = 0L, tmpMax = 0L, tmpFil = 0L;
                     if (minObj != null) tmpMin = ((long[])minObj)[0];
                     if (maxObj != null) tmpMax = ((long[])maxObj)[0];
                     if (filObj != null) tmpFil = ((long[])filObj)[0];
-                    if (tmpMin < 0) tmpMin -= (long) 2*Integer.MIN_VALUE;
-                    if (tmpMax < 0) tmpMax -= (long) 2*Integer.MIN_VALUE;
-                    if (tmpFil < 0) tmpFil -= (long) 2*Integer.MIN_VALUE;
-
+                    if (dataType == CDF_UINT4) {
+                      if (tmpMin < 0) tmpMin -= (long) 2*Integer.MIN_VALUE;
+                      if (tmpMax < 0) tmpMax -= (long) 2*Integer.MIN_VALUE;
+                      if (tmpFil < 0) tmpFil -= (long) 2*Integer.MIN_VALUE;
+                    }
                     for (int j = 0; j < (int) dimSizes[0]; j++) {
                       goon = true;
                       along = ((long [])_dataArray)[j];
-                      if (along < 0) along -= (long) 2*Integer.MIN_VALUE;
+                      if (dataType == CDF_UINT4)
+                        if (along < 0) along -= (long) 2*Integer.MIN_VALUE;
                       if (minObj != null) {
                           if (minLen == 1) {
                             if (along < tmpMin) {
@@ -804,7 +807,8 @@ public class ExportCreateCDF implements CDFConstants, Runnable {
                           } else {
 			    if (((long [])minObj).length > j) {
                               long avalue = ((long [])minObj)[j];
-                              if (avalue < 0) avalue -= (long) 2*Integer.MIN_VALUE;
+                              if (dataType == CDF_UINT4)
+                                if (avalue < 0) avalue -= (long) 2*Integer.MIN_VALUE;
                               if (along < avalue) {
                                 goon = false;                          
                                 if (filObj != null) ((long [])_dataArray)[j] = tmpFil;
@@ -822,7 +826,8 @@ public class ExportCreateCDF implements CDFConstants, Runnable {
                           } else {
 			    if (((long [])maxObj).length > j) {
                               long avalue = ((long [])maxObj)[j];
-                              if (avalue < 0) avalue -= (long) 2*Integer.MIN_VALUE;
+                              if (dataType == CDF_UINT4)
+                                if (avalue < 0) avalue -= (long) 2*Integer.MIN_VALUE;
                               if (along > avalue) {
                                 if (filObj != null) ((long [])_dataArray)[j] = tmpFil;
                                 else ((long [])_dataArray)[j] = 0;
@@ -1236,23 +1241,25 @@ public class ExportCreateCDF implements CDFConstants, Runnable {
                            }
                         }
 		    }
-		} else if (dataType == CDF_UINT4) {
+		} else if (dataType == CDF_UINT4 || dataType == CDF_INT8 ||
+                           dataType == CDF_TIME_TT2000) {
                     long along = 0;
                     long tmpMin = 0L, tmpMax = 0L, tmpFil = 0L;
                     if (minObj != null) tmpMin = ((long[])minObj)[0];
                     if (maxObj != null) tmpMax = ((long[])maxObj)[0];
                     if (filObj != null) tmpFil = ((long[])filObj)[0];
-                    if (tmpMin < 0) tmpMin -= (long) 2*Integer.MIN_VALUE;
-                    if (tmpMax < 0) tmpMax -= (long) 2*Integer.MIN_VALUE;
-                    if (tmpFil < 0) tmpFil -= (long) 2*Integer.MIN_VALUE;
-
+                    if (dataType == CDF_UINT4) {
+                      if (tmpMin < 0) tmpMin -= (long) 2*Integer.MIN_VALUE;
+                      if (tmpMax < 0) tmpMax -= (long) 2*Integer.MIN_VALUE;
+                      if (tmpFil < 0) tmpFil -= (long) 2*Integer.MIN_VALUE;
+                    }
                     for (int i = 0; i < (int) dimSizes[(int)nDims-2]; i++) {
                         aRow = (long [])Array.get(subArrays[(int)nDims - 2], i);
                         for (int j = 0; j < (int) dimSizes[nDims - 1]; j++) {
                            goon = true;
 			   along = ((long [])aRow)[j];
-			   if (along < 0) along -= (long) 2*Integer.MIN_VALUE;
-
+			   if (dataType == CDF_UINT4)
+                             if (along < 0) along -= (long) 2*Integer.MIN_VALUE;
                            if (minObj != null) {
                              if (minLen == 1) {
                                if (along < tmpMin) {
@@ -1263,7 +1270,8 @@ public class ExportCreateCDF implements CDFConstants, Runnable {
                              } else {
 			       if (((long [])minObj).length > j) {
                                  long avalue = ((long [])minObj)[j];
-                                 if (avalue < 0) avalue -= (long) 2*Integer.MIN_VALUE;
+                                 if (dataType == CDF_UINT4)
+                                   if (avalue < 0) avalue -= (long) 2*Integer.MIN_VALUE;
                                  if (along < avalue) {
 				   goon = false;
                                    if (filObj != null) ((long [])aRow)[j] = tmpFil;
@@ -1281,7 +1289,8 @@ public class ExportCreateCDF implements CDFConstants, Runnable {
                              } else {
 			       if (((long [])maxObj).length > j) {
                                  long avalue = ((long [])maxObj)[j];
-                                 if (avalue < 0) avalue -= (long) 2*Integer.MIN_VALUE;
+                                 if (dataType == CDF_UINT4)
+                                   if (avalue < 0) avalue -= (long) 2*Integer.MIN_VALUE;
                                  if (along > avalue) {
                                    if (filObj != null) ((long [])aRow)[j] = tmpFil;
                                    else ((long [])aRow)[j] = 0;
