@@ -1,4 +1,4 @@
-// $Id: NewEntryDialog.java,v 1.1.1.1 2010/01/13 20:06:14 liu Exp $
+// $Id: NewEntryDialog.java,v 1.1 2012/05/18 17:44:27 liu Exp $
 
 import javax.swing.*;
 import javax.swing.border.*;
@@ -103,7 +103,7 @@ public class NewEntryDialog extends JDialog implements CDFConstants, ActionListe
         gbl.setConstraints(tfen, gbc);
         sp.add(tfen);
 
-	Vector types = new Vector(15);
+	Vector types = new Vector(17);
 	types.addElement("CDF_BYTE");
 	types.addElement("CDF_INT1");
 	types.addElement("CDF_UINT1");
@@ -111,12 +111,14 @@ public class NewEntryDialog extends JDialog implements CDFConstants, ActionListe
 	types.addElement("CDF_UINT2");
 	types.addElement("CDF_INT4");
 	types.addElement("CDF_UINT4");
+	types.addElement("CDF_INT8");
 	types.addElement("CDF_REAL4");
 	types.addElement("CDF_FLOAT");
 	types.addElement("CDF_REAL8");
 	types.addElement("CDF_DOUBLE");
 	types.addElement("CDF_EPOCH");
 	types.addElement("CDF_EPOCH16");
+	types.addElement("CDF_TIME_TT2000");
 	types.addElement("CDF_CHAR");
 	types.addElement("CDF_UCHAR");
 
@@ -248,14 +250,16 @@ public class NewEntryDialog extends JDialog implements CDFConstants, ActionListe
 		case 4:  dataType = CDFConstants.CDF_UINT2;  break;
 		case 5:  dataType = CDFConstants.CDF_INT4;   break;
 		case 6:  dataType = CDFConstants.CDF_UINT4;  break;
-		case 7:  dataType = CDFConstants.CDF_REAL4;  break;
-		case 8:  dataType = CDFConstants.CDF_FLOAT;  break;
-		case 9:  dataType = CDFConstants.CDF_REAL8;  break;
-		case 10: dataType = CDFConstants.CDF_DOUBLE; break;
-		case 11: dataType = CDFConstants.CDF_EPOCH;  break;
-		case 12: dataType = CDFConstants.CDF_EPOCH16;  break;
-		case 13: dataType = CDFConstants.CDF_CHAR;   break;
-		case 14: dataType = CDFConstants.CDF_UCHAR;  break;
+		case 7:  dataType = CDFConstants.CDF_INT8;  break;
+		case 8:  dataType = CDFConstants.CDF_REAL4;  break;
+		case 9:  dataType = CDFConstants.CDF_FLOAT;  break;
+		case 10:  dataType = CDFConstants.CDF_REAL8;  break;
+		case 11: dataType = CDFConstants.CDF_DOUBLE; break;
+		case 12: dataType = CDFConstants.CDF_EPOCH;  break;
+		case 13: dataType = CDFConstants.CDF_EPOCH16;  break;
+		case 14: dataType = CDFConstants.CDF_TIME_TT2000;  break;
+		case 15: dataType = CDFConstants.CDF_CHAR;   break;
+		case 16: dataType = CDFConstants.CDF_UCHAR;  break;
 		    // keep compiler happy
 		default: dataType = CDFConstants.CDF_BYTE;   break;
 		}
