@@ -1,4 +1,4 @@
-// $Id: NewVariableDialog.java,v 1.1.1.1 2010/01/13 20:06:14 liu Exp $
+// $Id: NewVariableDialog.java,v 1.1 2012/05/18 17:44:27 liu Exp $
 
 import javax.swing.*;
 import javax.swing.border.*;
@@ -102,7 +102,7 @@ public class NewVariableDialog extends JDialog implements CDFConstants,
 	gbl.setConstraints(jtfvn, gbc);
 	rsp.add(jtfvn);
 	
-	Vector types = new Vector(15);
+	Vector types = new Vector(17);
 	types.addElement("CDF_BYTE");
 	types.addElement("CDF_INT1");
 	types.addElement("CDF_UINT1");
@@ -110,12 +110,14 @@ public class NewVariableDialog extends JDialog implements CDFConstants,
 	types.addElement("CDF_UINT2");
 	types.addElement("CDF_INT4");
 	types.addElement("CDF_UINT4");
+	types.addElement("CDF_INT8");
 	types.addElement("CDF_REAL4");
 	types.addElement("CDF_FLOAT");
 	types.addElement("CDF_REAL8");
 	types.addElement("CDF_DOUBLE");
 	types.addElement("CDF_EPOCH");
 	types.addElement("CDF_EPOCH16");
+	types.addElement("CDF_TIME_TT2000");
 	types.addElement("CDF_CHAR");
 	types.addElement("CDF_UCHAR");
 
@@ -601,14 +603,16 @@ public class NewVariableDialog extends JDialog implements CDFConstants,
 		    case 4:  dataType = CDF_UINT2;  break;
 		    case 5:  dataType = CDF_INT4;   break;
 		    case 6:  dataType = CDF_UINT4;  break;
-		    case 7:  dataType = CDF_REAL4;  break;
-		    case 8:  dataType = CDF_FLOAT;  break;
-		    case 9:  dataType = CDF_REAL8;  break;
-		    case 10: dataType = CDF_DOUBLE; break;
-		    case 11: dataType = CDF_EPOCH;  break;
-		    case 12: dataType = CDF_EPOCH16;  break;
-		    case 13: dataType = CDF_CHAR;   break;
-		    case 14: dataType = CDF_UCHAR;  break;
+		    case 7:  dataType = CDF_INT8;  break;
+		    case 8:  dataType = CDF_REAL4;  break;
+		    case 9:  dataType = CDF_FLOAT;  break;
+		    case 10:  dataType = CDF_REAL8;  break;
+		    case 11: dataType = CDF_DOUBLE; break;
+		    case 12: dataType = CDF_EPOCH;  break;
+		    case 13: dataType = CDF_EPOCH16;  break;
+		    case 14: dataType = CDF_TIME_TT2000;  break;
+		    case 15: dataType = CDF_CHAR;   break;
+		    case 16: dataType = CDF_UCHAR;  break;
 		    // keep compiler happy
 		    default: dataType = CDF_BYTE;   break;
 		  }
