@@ -877,10 +877,10 @@ public class SkeletonCDF extends JFrame
                 ind = myfile.lastIndexOf(".CDF");
                 if (ind != -1) myfile = myfile.substring(0, ind);
              } else { // for .skt file
-                ind = myfile.lastIndexOf(".skt");
-                if (ind != -1) myfile = myfile.substring(0, ind);
-                ind = myfile.lastIndexOf(".SKT");
-                if (ind != -1) myfile = myfile.substring(0, ind);
+//              ind = myfile.lastIndexOf(".skt");
+//              if (ind != -1) myfile = myfile.substring(0, ind);
+//              ind = myfile.lastIndexOf(".SKT");
+//              if (ind != -1) myfile = myfile.substring(0, ind);
              }
 	     fileChooser.setCurrentDirectory(selectedFile);
              textField.setText(myfile);
