@@ -243,8 +243,8 @@ public class SkeletonTable extends JFrame
     }
 
     SkeletonTable(JFrame parentDriver, String cdfbase, boolean modal) {
-        if (cdfbase != null) command = cdfbase + separator + "bin" + 
-				       separator + "skeletontable ";
+        if (cdfbase != null) command = "\"" + cdfbase + separator + "bin" + 
+				       separator + "skeletontable\" ";
 	dialog = new JDialog(this, modal);
 	this.parentDriver = parentDriver;
 	this.modal = modal;
