@@ -1,4 +1,4 @@
-//$Id: VariableSpecPanel.java,v 1.1.1.1 2010/01/13 20:06:14 liu Exp $
+//$Id: VariableSpecPanel.java,v 1.1 2012/05/18 17:44:27 liu Exp $
 
 // Swing Imports
 import javax.swing.*;
@@ -201,7 +201,8 @@ public class VariableSpecPanel extends JLabeledPanel implements CDFConstants {
         if (padValue == null)
           padString = "";
         else {
-          if (dataType != CDF_EPOCH && dataType != CDF_EPOCH16) {
+          if (dataType != CDF_EPOCH && dataType != CDF_EPOCH16 &&
+              dataType != CDF_TIME_TT2000) {
             padString = padValue.toString();
 	    pad.set(padString);
             if (((String)pad.get()).length() >= 15) 
@@ -216,12 +217,17 @@ public class VariableSpecPanel extends JLabeledPanel implements CDFConstants {
 	      pad.set(padString);
               pad.textField.setFont(new Font(padCurrFont.getName(), padCurrFont.getStyle(), 
 					     padCurrFont.getSize()-3));
-	    } else {
+	    } else if (dataType == CDF_EPOCH16) {
               padString = Epoch16.encode(((double[])padValue));
               pad.set(padString);
               pad.textField.setFont(new Font(padCurrFont.getName(), padCurrFont.getStyle(),
                                              padCurrFont.getSize()-5));
-	    }
+	    } else {
+              padString = CDFTT2000.toUTCstring(((Long)padValue).longValue());
+              pad.set(padString);
+              pad.textField.setFont(new Font(padCurrFont.getName(), padCurrFont.getStyle(),
+                                             padCurrFont.getSize()-3));
+            }
 	  }
         }
 
