@@ -1,4 +1,4 @@
-//$Id: VariableValuePanel.java,v 1.2 2011/01/14 18:14:54 liu Exp $
+//$Id: VariableValuePanel.java,v 1.2 2012/06/21 13:12:58 liu Exp $
 
 // Swing Imports
 import javax.swing.*;
@@ -261,6 +261,8 @@ public class VariableValuePanel extends JLabeledPanel implements CDFConstants,
             output = Epoch.encode(((Double)datavalue).doubleValue());
           else if (dataType == CDF_EPOCH16)
             output = Epoch16.encode((double[])datavalue);
+          else if (dataType == CDF_TIME_TT2000)
+            output = CDFTT2000.toUTCstring(((Long)datavalue).longValue());
 	  else {
             if (dataType == CDF_CHAR || dataType == CDF_UCHAR) {
               if (((String)datavalue).length() >= numElements)
@@ -299,6 +301,7 @@ public class VariableValuePanel extends JLabeledPanel implements CDFConstants,
               case (int) CDF_UINT2:
               case (int) CDF_INT4:
               case (int) CDF_UINT4:
+              case (int) CDF_INT8:
                 output = "0";
                 break;
               case (int) CDF_REAL4:
@@ -312,6 +315,9 @@ public class VariableValuePanel extends JLabeledPanel implements CDFConstants,
               case (int) CDF_EPOCH16:
                 output = "01-Jan-0000 00:00:00.000.000.000.000";
                 break;
+              case (int) CDF_TIME_TT2000:
+                output = "0000-01-01T00:00:00.000.000000000";
+                break;
               case (int) CDF_CHAR:
               case (int) CDF_UCHAR:
 		StringBuffer tmp = new StringBuffer();
@@ -323,7 +329,8 @@ public class VariableValuePanel extends JLabeledPanel implements CDFConstants,
                 break;
             }
           } else {
-            if (dataType != CDF_EPOCH && dataType != CDF_EPOCH16) 
+            if (dataType != CDF_EPOCH && dataType != CDF_EPOCH16 &&
+                dataType != CDF_TIME_TT2000) 
 		output = padValue.toString();
             else {
 		if (dataType == CDF_EPOCH) {
@@ -333,12 +340,18 @@ public class VariableValuePanel extends JLabeledPanel implements CDFConstants,
                     if (epoch < 0.0) epoch = 0.0;
                     output = Epoch.encode(epoch);
                   }
-		} else {
+		} else if (dataType == CDF_EPOCH16) {
                   if (padValue instanceof String) output = (String) padValue;
                   else {
                     output = Epoch16.encode((double[])padValue);
                   }
-		}
+		} else {
+                  if (padValue instanceof String) output = (String) padValue;
+                  else {
+                    long epoch = ((Long)padValue).longValue();
+                    output = CDFTT2000.toUTCstring(epoch);
+                  }
+                }
             }
           }
         }
@@ -448,6 +461,7 @@ public class VariableValuePanel extends JLabeledPanel implements CDFConstants,
 			changed = true;
 			break;
                 case (int) CDF_UINT4:  
+                case (int) CDF_INT8:  
 			valueX = new Long(newActualValue);
 			changed = true;
 			break;
@@ -488,6 +502,19 @@ public class VariableValuePanel extends JLabeledPanel implements CDFConstants,
                           cancel.setEnabled(false);
                         }
                         break;
+		case (int) CDF_TIME_TT2000:
+			try {
+			  valueX = new Long(CDFTT2000.fromUTCstring(newActualValue));
+			  changed = true;
+			} catch (CDFException ex) {
+			  Toolkit.getDefaultToolkit().beep();
+			  JOptionPane.showMessageDialog(myEditor.getFrame(),
+						"ILLEGAL_TT2000:"+newActualValue);
+			  showIndexData();
+                          update.setEnabled(false);
+                          cancel.setEnabled(false);
+			}
+			break;
                 case (int) CDF_CHAR:   
                 case (int) CDF_UCHAR: 
 			newActualValue = newActualValue.substring(1, 
