@@ -44,6 +44,12 @@ public interface CDFConstants {
     public static final long EPOCH3_STRING_LEN_EXTEND  = 36;
     public static final long EPOCH4_STRING_LEN_EXTEND  = 32;
 
+    public static final long TT2000_0_STRING_LEN  =  30;
+    public static final long TT2000_1_STRING_LEN  =  19;
+    public static final long TT2000_2_STRING_LEN  =  14;
+    public static final long TT2000_3_STRING_LEN  =  29;
+
+
     /*----------------*/
     /* CDF data types */
     /*----------------*/
@@ -51,6 +57,7 @@ public interface CDFConstants {
     public static final long CDF_INT1   = 1;
     public static final long CDF_INT2   = 2;
     public static final long CDF_INT4   = 4;
+    public static final long CDF_INT8   = 8;
     public static final long CDF_UINT1  = 11;
     public static final long CDF_UINT2  = 12;
     public static final long CDF_UINT4  = 14;
@@ -58,6 +65,7 @@ public interface CDFConstants {
     public static final long CDF_REAL8  = 22;
     public static final long CDF_EPOCH  = 31;    // Standard style
     public static final long CDF_EPOCH16= 32;    // Standard style
+    public static final long CDF_TIME_TT2000= 33;    // J2000 style
     public static final long CDF_BYTE   = 41;    // Same as CDF_INT1 (signed)
     public static final long CDF_FLOAT  = 44;    // Same as CDF_REAL4
     public static final long CDF_DOUBLE = 45;    // Same as CDF_REAL8
@@ -211,6 +219,7 @@ public interface CDFConstants {
     public static final int    DEFAULT_UINT2_PADVALUE	= 0;
     public static final int    DEFAULT_INT4_PADVALUE	= 0;
     public static final long   DEFAULT_UINT4_PADVALUE	= 0L;
+    public static final long   DEFAULT_INT8_PADVALUE	= 0L;
     public static final float  DEFAULT_REAL4_PADVALUE	= (float)0.0;
     public static final float  DEFAULT_FLOAT_PADVALUE	= (float)0.0;
     public static final double DEFAULT_REAL8_PADVALUE	= (double)0.0;
@@ -218,12 +227,15 @@ public interface CDFConstants {
     public static final char   DEFAULT_CHAR_PADVALUE	= ' ';
     public static final char   DEFAULT_UCHAR_PADVALUE	= ' ';
     public static final double DEFAULT_EPOCH_PADVALUE	= (double)0.0;
-
+    public static final long   DEFAULT_TT2000_PADVALUE	= -9223372036854775807L;
+                                       /* == 1710-01-01T00.00.00.000000000 */
     /*-------------------*/
     /* Invalid constants */ 
     /*-------------------*/
 
-    public static final long ILLEGAL_EPOCH_VALUE     = -1;
+    public static final double ILLEGAL_EPOCH_VALUE      = -1.0;
+    public static final long ILLEGAL_TT2000_VALUE       = -9223372036854775805L;
+    public static final long FILLED_TT2000_VALUE         = Long.MIN_VALUE;
 
     /*------------------------------------*/
     /* Status Codes - informational codes */
@@ -372,6 +384,8 @@ public interface CDFConstants {
     public static final long CHECKSUM_ERROR               = -2226;
     public static final long CHECKSUM_NOT_ALLOWED         = -2227;
     public static final long IS_A_NETCDF                  = -2228;
+    public static final long TT2000_TIME_ERROR            = -2229;
+    public static final long UNABLE_TO_PROCESS_CDF        = -2230;
 
     /*----------------------------------------------------------------*/
     /*  Functions (for INTERNAL interface).                           */
@@ -393,6 +407,7 @@ public interface CDFConstants {
     public static final long GETCDFCHECKSUM_ =          1013;
     public static final long VALIDATE_ =                1014;
     public static final long GETCDFVALIDATE_ =          1015;
+    public static final long GETLEAPSECONDSENVVAR_ =    1016;
 
     public static final long NULL_ =			1000;
 
