@@ -1,4 +1,4 @@
-//$Id: CDFData.java,v 1.2 2010/06/10 17:03:25 liu Exp $
+//$Id: CDFData.java,v 1.1 2012/05/18 17:48:50 liu Exp $
 package gsfc.nssdc.cdf;
 
 import java.lang.*;
@@ -508,6 +508,13 @@ synchronized(v) {
 		throw new CDFException(DATATYPE_MISMATCH);
 	    }
 	    break;
+	case (int)CDF_INT8: 
+	case (int)CDF_TIME_TT2000: 
+	    if ((dataClassName.indexOf("[J") == -1) &&
+		(dataClassName.indexOf("Long") == -1)) {
+		throw new CDFException(DATATYPE_MISMATCH);
+	    }
+	    break;
 	case (int)CDF_REAL4:
 	case (int)CDF_FLOAT: 
 	    if ((dataClassName.indexOf("[F") == -1) &&
@@ -737,6 +744,13 @@ synchronized(v) {
 					 (int)dimSizes[(int)nDims-1]);
 			n += dimSizes[(int)nDims-1];
 			break;
+		    case (int)CDF_INT8:
+		    case (int)CDF_TIME_TT2000:
+			aRow = new long[(int)dimSizes[(int)nDims-1]];
+			System.arraycopy(_data, n, aRow, 0, 
+					 (int)dimSizes[(int)nDims-1]);
+			n += dimSizes[(int)nDims-1];
+			break;
 		    case (int)CDF_REAL4:
 		    case (int)CDF_FLOAT:
 			aRow = new float[(int)dimSizes[(int)nDims-1]];
@@ -897,6 +911,13 @@ synchronized(v) {
 					 dimSizes[(int)nDims-1]);
 			n += dimSizes[(int)nDims-1];
 			break;
+		    case (int)CDF_INT8:
+		    case (int)CDF_TIME_TT2000:
+			aRow = (long [])Array.get(subArrays[(int)nDims - 2], i);
+			System.arraycopy(aRow, 0, _data, n, 
+					 dimSizes[(int)nDims-1]);
+			n += dimSizes[(int)nDims-1];
+			break;
 		    case (int)CDF_REAL4:
 		    case (int)CDF_FLOAT:
 			aRow = (float [])Array.get(subArrays[(int)nDims - 2], i);
@@ -1025,7 +1046,9 @@ synchronized(v) {
 	case (int)CDF_UINT1: className = "[S";                 break;
 	case (int)CDF_INT4:
 	case (int)CDF_UINT2: className = "[I";                 break;
-	case (int)CDF_UINT4: className = "[J";                 break;
+	case (int)CDF_UINT4:
+	case (int)CDF_INT8:
+	case (int)CDF_TIME_TT2000: className = "[J";           break;
 	case (int)CDF_REAL4:
 	case (int)CDF_FLOAT: className = "[F";                 break;
 	case (int)CDF_REAL8:
@@ -1155,19 +1178,30 @@ synchronized(v) {
 	    }
 	    break;
 	case (int)CDF_UINT4:
+	case (int)CDF_INT8:
+	case (int)CDF_TIME_TT2000:
 	    if (numValues > 1) {
 		dataSignature = "[J";
 		_data = new long [(int)numValues];
                 if (padValue == null)
                   for (int i=0; i<numValues; i++)
-                        ((long [])_data)[i] = (long)DEFAULT_UINT4_PADVALUE;
+                     ((long [])_data)[i] = 
+                      (long)((dataTypeX == (int) CDF_UINT4) ? 
+                             DEFAULT_UINT4_PADVALUE :
+                             ((dataTypeX == (int) CDF_INT8) ?
+                               DEFAULT_INT8_PADVALUE :
+                               DEFAULT_TT2000_PADVALUE));
                 else
                     for (int i=0; i<numValues; i++)
                         ((long [])_data)[i] = ((Long)padValue).longValue();
 	    } else {
 		dataSignature = "Ljava/lang/Long;";
 		if (padValue == null)
-		  _data = new Long((long)DEFAULT_UINT4_PADVALUE);
+		  _data = new Long((dataTypeX == (int) CDF_UINT4) ?
+                                   DEFAULT_UINT4_PADVALUE :
+                                   ((dataTypeX == (int) CDF_INT8) ?
+                                     DEFAULT_INT8_PADVALUE :
+                                     DEFAULT_TT2000_PADVALUE));
 		else
 		  _data = new Long(((Long)padValue).longValue());
 	    }
@@ -1285,13 +1319,17 @@ synchronized(v) {
                 } else if (_myVar.getDataType() == CDF_EPOCH16) {
                     double[] lEpoch16 = (double[]) _dataArray;
                     System.out.println (Epoch16.encode(lEpoch16));
+                } else if (_myVar.getDataType() == CDF_TIME_TT2000) {
+                    Long lEpoch = (Long) _dataArray;
+                    System.out.println (CDFTT2000.encode(lEpoch.longValue()));
                 }
                 else
                     System.out.println(_dataArray.toString());
             }
             else {
                 System.out.print("[");
-                switch ((int)_myVar.getDataType()) {
+                int dataTypeX = (int)_myVar.getDataType();
+                switch (dataTypeX) {
                 case (int)CDF_CHAR:
                 case (int)CDF_UCHAR:
                     for (int j=0; j<dimSizes[nDims - 1]; j++) {
@@ -1353,6 +1391,16 @@ synchronized(v) {
 			}
                     }
                     break;
+                case (int)CDF_INT8:
+                case (int)CDF_TIME_TT2000:
+                    for (int j=0; j<dimSizes[nDims - 1]; j++) {
+                        if (j>0) System.out.print(",");
+                        if (dataTypeX == (int)CDF_INT8)
+                          System.out.print(((long [])_dataArray)[j]);
+                        else
+                          System.out.print(CDFTT2000.encode(((long [])_dataArray)[j]));
+                    }
+                    break;
                 case (int)CDF_REAL4:
                 case (int)CDF_FLOAT:
                     for (int j=0; j<dimSizes[nDims - 1]; j++) {
@@ -1448,7 +1496,8 @@ synchronized(v) {
                 // Fill the correct elements of _data
                 for (int i=0;i<dimSizes[(int)nDims-2];i++) {
                     System.out.print("[");
-                    switch ((int)_myVar.getDataType()) {
+                    int dataTypeX = (int)_myVar.getDataType();
+                    switch (dataTypeX) {
                     case (int)CDF_CHAR:
                     case (int)CDF_UCHAR:
                         aRow =
@@ -1517,6 +1566,17 @@ synchronized(v) {
                             }
                         }
                         break;
+                    case (int)CDF_INT8:
+                    case (int)CDF_TIME_TT2000:
+                        aRow = (long [])Array.get(subArrays[(int)nDims - 2], i);
+                        for (int j=0; j<dimSizes[nDims - 1]; j++) {
+                            if (j>0) System.out.print(",");
+                            if (dataTypeX == (int)CDF_INT8)
+                              System.out.print(((long [])aRow)[j]);
+                            else
+                              System.out.print(CDFTT2000.encode(((long [])aRow)[j]));
+                        }
+                        break;
                     case (int)CDF_REAL4:
                     case (int)CDF_FLOAT:
                         aRow = (float [])Array.get(subArrays[(int)nDims - 2], i);
