@@ -1,4 +1,4 @@
-// $Id: CDFException.java,v 1.2 2010/03/04 15:12:15 liu Exp $
+// $Id: CDFException.java,v 1.1 2012/05/18 17:48:50 liu Exp $
 package gsfc.nssdc.cdf;
 
 import gsfc.nssdc.cdf.util.*;
@@ -236,6 +236,10 @@ public class CDFException
 	msgs.put(new Long(CHECKSUM_NOT_ALLOWED), "The checksum is not allowed"+
 		" for old versioned files.");
 	msgs.put(new Long(IS_A_NETCDF), "Named CDF is actually a netCDF file.");
+        msgs.put(new Long(TT2000_TIME_ERROR), "Error handling the date/time "+
+                 "for TT2000 or a TT2000 epoch."); 
+        msgs.put(new Long(UNABLE_TO_PROCESS_CDF), "One of data fields is "+
+                 "invalid... Upgrade the library might fix the problem.");
     }
 
     /**
