@@ -1,4 +1,4 @@
-//$Id: Entry.java,v 1.1.1.1 2010/01/13 20:06:14 liu Exp $
+//$Id: Entry.java,v 1.1 2012/05/18 17:48:50 liu Exp $
 
 package gsfc.nssdc.cdf;
 
@@ -148,6 +148,12 @@ synchronized(myAttribute) {
 
 	theEntry.myAttribute.getMyCDF().executeCommand((CDFObject)theEntry, 
 						       cmds);
+        /* Make sure the exception is thrown if a bad status is returned
+           while JNI does not issue it. */
+/*
+	long status = theEntry.myAttribute.getMyCDF().getStatus();
+        if (status < CDF_WARN) throw new CDFException(status);
+*/
 
         /********************/
 	/* Get the data out */
@@ -230,12 +236,14 @@ synchronized(myAttribute) {
      *                    <LI>CDF_UNIT2    - 2-byte, unsigned integer
      *                    <LI>CDF_INT4     - 4-byte, signed integer
      *                    <LI>CDF_UINT4    - 4-byte, unsigned integer
+     *                    <LI>CDF_INT8     - 8-byte, signed integer
      *                    <LI>CDF_REAL4    - 4-byte, floating point 
      *                    <LI>CDF_FLOAT    - 4-byte, floating point 
      *                    <LI>CDF_REAL8    - 8-byte, floating point 
      *                    <LI>CDF_DOUBLE   - 8-byte, floating point 
      *                    <LI>CDF_EPOCH    - 8-byte, floating point 
      *                    <LI>CDF_EPOCH16  - 2*8-byte, floating point
+     *                    <LI>CDF_TIME_TT2000  - 8-byte, signed integer
      *                 </UL>
      * @param data the entry data to be added <P>
      *
@@ -372,6 +380,16 @@ synchronized(myAttribute) {
 		    data = new Long(0L);
 		}
 		break;
+	    case (int)CDF_INT8:
+	    case (int)CDF_TIME_TT2000:
+		if (numElements > 1) {
+		    data = new long [(int)numElements];
+		    dataSignature = "[J";
+		} else {
+		    dataSignature = "Ljava/lang/Long;";
+		    data = new Long(0L);
+		}
+		break;
 	    case (int)CDF_REAL4:
 	    case (int)CDF_FLOAT:
 		if (numElements > 1) {
