@@ -1,4 +1,4 @@
-// $Id: Variable.java,v 1.2 2010/06/10 17:03:25 liu Exp $
+// $Id: Variable.java,v 1.3 2012/06/27 20:49:17 liu Exp $
 package gsfc.nssdc.cdf;
 
 import java.util.*;
@@ -347,12 +347,14 @@ synchronized(myCDF) {
      *                    <LI>CDF_UNIT2  - 2-byte, unsigned integer
      *                    <LI>CDF_INT4   - 4-byte, signed integer
      *                    <LI>CDF_UINT4  - 4-byte, unsigned integer
+     *                    <LI>CDF_INT8   - 8-byte, signed integer
      *                    <LI>CDF_REAL4  - 4-byte, floating point
      *                    <LI>CDF_FLOAT  - 4-byte, floating point
      *                    <LI>CDF_REAL8  - 8-byte, floating point
      *                    <LI>CDF_DOUBLE - 8-byte, floating point
      *                    <LI>CDF_EPOCH  - 8-byte, floating point
      *                    <LI>CDF_EPOCH16  - 2*8-byte, floating point
+     *                    <LI>CDF_TIME_TT2000  - 8-byte, signed integer
      *                 </UL>
      * @param numElements for CDF_CHAR and CDF_UCHAR this is the 
      *                    string length, 1 otherwise <P>
@@ -1754,9 +1756,7 @@ synchronized(myCDF) {
      * @return the ID of this variable 
      */
     public synchronized long getID() {
-
 	return myCDF.getVariableID(name);
-
     }
     
     /**
@@ -1908,6 +1908,8 @@ synchronized(myCDF) {
 		dataSignature = "Ljava/lang/Integer;";
 		break;
 	    case (int)CDF_UINT4:
+	    case (int)CDF_INT8:
+	    case (int)CDF_TIME_TT2000:
 		dataSignature = "Ljava/lang/Long;";
 		break;
 	    case (int)CDF_REAL4:
@@ -2860,23 +2862,23 @@ synchronized(myCDF) {
 
         try {
             v = this.myCDF.getVariable(this.getName());
-        } catch (CDFException ex) {
-        }
-        Vector attrs = new Vector();
-        Vector va = this.myCDF.getVariableAttributes();
+            Vector attrs = new Vector();
+            Vector va = this.myCDF.getVariableAttributes();
 
-        for (Enumeration e=va.elements(); e.hasMoreElements();) {
-             Attribute a = (Attribute) e.nextElement();
-             try {
+            for (Enumeration e=va.elements(); e.hasMoreElements();) {
+              Attribute a = (Attribute) e.nextElement();
+              try {
                   Entry entry = a.getEntry(v);
                   if (entry != null) {
                       attrs.addElement(a);
                   }
-             } catch (CDFException ex) {   // No attribute entry exists
-             }
+              } catch (CDFException ex) {   // No attribute entry exists
+              }
+            }
+            return attrs;
+        } catch (CDFException ex) { 
+          return new Vector();
         }
-        return attrs;
-
     }
 
 }
