@@ -1,4 +1,4 @@
-// $Id: CDFUtils.java,v 1.4 2011/01/05 16:23:05 liu Exp $
+// $Id: CDFUtils.java,v 1.1 2012/05/18 17:47:39 liu Exp $
 
 package gsfc.nssdc.cdf.util;
 
@@ -98,7 +98,18 @@ public class CDFUtils implements CDFConstants {
 				      Object data)
 	throws CDFException {
 	if ((dataType == CDF_CHAR) || (dataType == CDF_UCHAR)) {
-	    return((String)data).length();
+            String signature = CDFUtils.getSignature(data);
+            if (signature.indexOf("String") != -1) {
+              try {
+                byte[] bytes = ((String)data).getBytes("UTF-8");
+                return (bytes.length);
+              } catch (Exception exp) {
+	        return((String)data).length();
+              }
+            }
+            else if (signature.indexOf("[B") != -1)
+              return((byte[])data).length;
+            else return 1;
 	}
 	else {
 	    int which = (dataType == CDF_EPOCH16 ? 2 : 1);
@@ -145,6 +156,7 @@ public class CDFUtils implements CDFConstants {
      *
      *  @param data the data to be printed
      *  @param which the Epoch data type data indicator
+     *               1 if CDF_EPOCH, 2 if CDF_EPOCH16 or 3 if CDF_TIME_TT2000
      *  @param iso8601 the ISO 8601 indicator for EPOCH data
      *
      */
@@ -166,7 +178,10 @@ public class CDFUtils implements CDFConstants {
                      System.out.print (Array.getInt(data,i)+" ");
 
                  else if (signature.charAt(1) == 'J')
-                     System.out.print (Array.getLong(data,i)+" ");
+                     if (which == 0)
+                       System.out.print (Array.getLong(data,i)+" ");
+                     else
+                       System.out.print (CDFTT2000.encode(Array.getLong(data,i))+" ");
 
                  else if (signature.charAt(1) == 'F')
                      System.out.print (Array.getFloat(data,i)+" ");
@@ -194,6 +209,8 @@ public class CDFUtils implements CDFConstants {
              System.out.print (((!iso8601)?
                                 Epoch.encode(((Double)data).doubleValue()):
                                 Epoch.encode4(((Double)data).doubleValue())));
+           else if (which == 3)
+             System.out.print (CDFTT2000.encode(((Long)data).longValue()));
            else
              System.out.print (data);
 	}
@@ -207,6 +224,7 @@ public class CDFUtils implements CDFConstants {
      *
      *  @param data the data to be printed
      *  @param which the Epoch data type data indicator
+     *               1 if CDF_EPOCH, 2 if CDF_EPOCH16 or 3 if CDF_TIME_TT2000
      *
      */
     public static void printData (Object data, int which) {
@@ -242,11 +260,36 @@ public class CDFUtils implements CDFConstants {
 	printData(data, outWriter, 0, false);
     }
 
+    /**
+     *  Prints the value of the given data to the place designated by
+     *  PrintWriter that can be a file, Sysem.out, System.err, and etc.  
+     *  Data can be a java primitive data type, Java Object (non-array), or 
+     *  1-dimensional array of primitive Java data type. <P>
+     *
+     *  @param data the data to be printed <P>
+     *  @param outWriter the print writer to which formatted representations 
+     *                   of the object/data is printed as a text-output stream
+     *  @param which the Epoch data type data indicator
+     *               1 if CDF_EPOCH, 2 if CDF_EPOCH16 or 3 if CDF_TIME_TT2000
+     */
     public static void printData (Object data, PrintWriter outWriter,
 				  int which) {
         printData(data, outWriter, which, false);
     }
 
+    /**
+     *  Prints the value of the given data to the place designated by
+     *  PrintWriter that can be a file, Sysem.out, System.err, and etc.  
+     *  Data can be a java primitive data type, Java Object (non-array), or 
+     *  1-dimensional array of primitive Java data type. <P>
+     *
+     *  @param data the data to be printed <P>
+     *  @param outWriter the print writer to which formatted representations 
+     *                   of the object/data is printed as a text-output stream
+     *  @param which the Epoch data type data indicator
+     *               1 if CDF_EPOCH, 2 if CDF_EPOCH16 or 3 if CDF_TIME_TT2000
+     *  @param iso8601 the ISO 8601 indicator for EPOCH data
+     */
     public static void printData (Object data, PrintWriter outWriter,
 				  int which, boolean iso8601) {
 
@@ -267,7 +310,10 @@ public class CDFUtils implements CDFConstants {
                      outWriter.print (Array.getInt(data,i)+" ");
 
                  else if (signature.charAt(1) == 'J')
-                     outWriter.print (Array.getLong(data,i)+" ");
+                     if (which == 0)
+                       outWriter.print (Array.getLong(data,i)+" ");
+                     else
+                       outWriter.print (CDFTT2000.encode(Array.getLong(data,i))+" ");
 
                  else if (signature.charAt(1) == 'F')
                      outWriter.print (Array.getFloat(data,i)+" ");
@@ -296,6 +342,8 @@ public class CDFUtils implements CDFConstants {
 	     outWriter.print (((!iso8601)?
                                Epoch.encode(((Double)data).doubleValue()):
                                Epoch.encode4(((Double)data).doubleValue())));
+           else if (which == 3)
+             outWriter.print (CDFTT2000.encode(((Long)data).longValue()));
            else
 	     outWriter.print (data);
 	}
@@ -362,7 +410,8 @@ public class CDFUtils implements CDFConstants {
      *  @param data the data to be parsed <P>
      *  @param separator the delimiter for array elements <P>
      *  @param epochType Epoch or Epoch16 data type indicator <BR>
-     *         == 1 for EPOCH, == 2 for EPOCH16, == 0 other data types <P>
+     *         == 1 for EPOCH, == 2 for EPOCH16, == 3 for TT2000, 
+     *         == 0 for other data types <P>
      *  @return The string value of the given data/object. <BR>
      *          If the data is an array, its elements are delimited by 
      *          the user defined separator. 
@@ -378,40 +427,46 @@ public class CDFUtils implements CDFConstants {
         if (signature.charAt(0) == '[') {
             arrayLength = Array.getLength(data);
             for (i=0; i < arrayLength; i=i+jj) {
+                 if (i > 0) buffer.append(separator);
                  if (signature.charAt(1) == 'B')
-		   buffer.append(Array.getByte(data,i)).append(separator);
+		   buffer.append(Array.getByte(data,i));
 
                  else if (signature.charAt(1) == 'S')
-		   buffer.append(Array.getShort(data,i)).append(separator);
+		   buffer.append(Array.getShort(data,i));
 
                  else if (signature.charAt(1) == 'I')
-		   buffer.append(Array.getInt(data,i)).append(separator);
+		   buffer.append(Array.getInt(data,i));
 
                  else if (signature.charAt(1) == 'J')
-		   buffer.append(Array.getLong(data,i)).append(separator);
+                   if (epochType == 0)
+		     buffer.append(Array.getLong(data,i));
+                   else {
+                     String tmp = CDFTT2000.encode(Array.getLong(data,i));
+                     buffer.append(tmp);
+                   }
 
                  else if (signature.charAt(1) == 'F')
-		   buffer.append(Array.getFloat(data,i)).append(separator);
+		   buffer.append(Array.getFloat(data,i));
 
                  else if (signature.charAt(1) == 'D') {
 		   if (epochType == 1) {
 		     String tmp = Epoch.encode(Array.getDouble(data,i));
-		     buffer.append(tmp).append(separator);
+		     buffer.append(tmp);
 		   } else if (epochType == 2) {
 		     double[] mmm = new double[2];
 		     mmm[0] = Array.getDouble(data,i);
 		     mmm[1] = Array.getDouble(data,i+1);
 		     String tmp = Epoch16.encode(mmm);
-		     buffer.append(tmp).append(separator);
+		     buffer.append(tmp);
 		   } else
-		     buffer.append(Array.getDouble(data,i)).append(separator);
+		     buffer.append(Array.getDouble(data,i));
 		 }
                  else if (signature.charAt(1) == 'C')
-                   buffer.append(Array.getChar(data,i)).append(separator);
+                   buffer.append(Array.getChar(data,i));
 		 else if (signature.indexOf("String") != -1)
-		   buffer.append(((String[])data)[i]).append(separator);
+		   buffer.append(((String[])data)[i]);
 	    }
-	     buffer.setLength(buffer.length() - separator.length());
+//	     buffer.setLength(buffer.length() - separator.length());
         } else {
                  if (signature.indexOf("Byte") != -1)    
                    buffer.append(((Byte)data).toString());
@@ -423,7 +478,10 @@ public class CDFUtils implements CDFConstants {
                    buffer.append(((Integer)data).toString());
 
                  else if (signature.indexOf("Long") != -1)
-                   buffer.append(((Long)data).toString());
+                   if (epochType == 0)
+                     buffer.append(((Long)data).toString());
+                   else
+                     buffer.append(CDFTT2000.encode(((Long)data).longValue()));
 
                  else if (signature.indexOf("Float") != -1)
                    buffer.append(((Float)data).toString());
@@ -431,7 +489,7 @@ public class CDFUtils implements CDFConstants {
                  else if (signature.indexOf("Double") != -1) {
 		   if (epochType == 1) {
                      String tmp = Epoch.encode(((Double)data).doubleValue());
-                     buffer.append(tmp).append(separator);
+                     buffer.append(tmp);
                    } else
                      buffer.append(((Double)data).toString());
 
@@ -484,12 +542,15 @@ public class CDFUtils implements CDFConstants {
      *             <LI>CDF_INT2</LI>
      *             <LI>CDF_UINT2</LI>
      *             <LI>CDF_INT4</LI>
-     *             <LI>CDF_UINT4</LI>
+     *             <LI>CDF_UINT8</LI>
+     *             <LI>CDF_INT8</LI>
      *             <LI>CDF_REAL4</LI>
      *             <LI>CDF_FLOAT</LI>
      *             <LI>CDF_REAL8</LI>
      *             <LI>CDF_DOUBLE</LI>
      *             <LI>CDF_EPOCH</LI>
+     *             <LI>CDF_EPOCH16</LI>
+     *             <LI>CDF_TIME_TT2000</LI>
      *          </UL><P>
      *  @return String representation of cdfDataType.  
      *          The returned value is one of the valid values describe above
@@ -526,6 +587,9 @@ public class CDFUtils implements CDFConstants {
         else if (cdfDataType == CDF_UINT4) 
             cDataType = "CDF_UINT4";
 
+        else if (cdfDataType == CDF_INT8) 
+            cDataType = "CDF_INT8";
+
         else if (cdfDataType == CDF_REAL4) 
             cDataType = "CDF_REAL4";
 
@@ -544,6 +608,9 @@ public class CDFUtils implements CDFConstants {
         else if (cdfDataType == CDF_EPOCH16)
             cDataType = "CDF_EPOCH16";
 
+        else if (cdfDataType == CDF_TIME_TT2000)
+            cDataType = "CDF_TIME_TT2000";
+
         else
             cDataType = "UNKNOWN";
 
@@ -567,11 +634,14 @@ public class CDFUtils implements CDFConstants {
      *             <LI>CDF_UINT2</LI>
      *             <LI>CDF_INT4</LI>
      *             <LI>CDF_UINT4</LI>
+     *             <LI>CDF_INT8</LI>
      *             <LI>CDF_REAL4</LI>
      *             <LI>CDF_FLOAT</LI>
      *             <LI>CDF_REAL8</LI>
      *             <LI>CDF_DOUBLE</LI>
      *             <LI>CDF_EPOCH</LI>
+     *             <LI>CDF_EPOCH16</LI>
+     *             <LI>CDF_TIME_TT2000</LI>
      *          </UL><P>
      *  @return long representation of cdfDataType.  The returned value is
      *          one of the valid values described above for cdfDataType.  -1 is
@@ -607,6 +677,9 @@ public class CDFUtils implements CDFConstants {
         else if (cdfDataType.equals( "CDF_UINT4"))
             lDataType = CDF_UINT4;
 
+        else if (cdfDataType.equals( "CDF_INT8"))
+            lDataType = CDF_INT8;
+
         else if (cdfDataType.equals( "CDF_REAL4"))
             lDataType = CDF_REAL4;
 
@@ -625,6 +698,9 @@ public class CDFUtils implements CDFConstants {
 	else if (cdfDataType.equals( "CDF_EPOCH16"))
 	    lDataType = CDF_EPOCH16;
 
+	else if (cdfDataType.equals( "CDF_TIME_TT2000"))
+	    lDataType = CDF_TIME_TT2000;
+
         else
             lDataType = -1;
 
