@@ -1,4 +1,4 @@
-// $Id: Epoch.java,v 1.3 2010/12/21 16:30:50 liu Exp $
+// $Id: Epoch.java,v 1.1 2012/05/18 17:47:39 liu Exp $
 package gsfc.nssdc.cdf.util;
 
 import gsfc.nssdc.cdf.CDFException;
@@ -754,7 +754,7 @@ public class Epoch implements gsfc.nssdc.cdf.CDFConstants {
 	 * is passed in for `month', assume that `day' is the day-of-year
 	 * (DOY) with January 1st being day 1.
 	 */
-        if (year < 0L) throw new CDFException(ILLEGAL_EPOCH_VALUE);
+        if (year < 0L) throw new CDFException(ILLEGAL_EPOCH_FIELD);
         if ((year > 9999L) || (month < 0L || month > 12L) ||
             (hour < 0L || hour > 23L) || (minute < 0L || minute > 59L) ||
             (second < 0L || second > 59L) || (msec < 0L || msec > 999L))
@@ -894,7 +894,7 @@ public class Epoch implements gsfc.nssdc.cdf.CDFConstants {
           daysSince0AD = JulianDay(y,m,d) - 1721060L;
         }
         if (daysSince0AD < 1L) 
-         throw new CDFException(ILLEGAL_EPOCH_VALUE);
+         throw new CDFException(ILLEGAL_EPOCH_FIELD);
         msecInDay = 3600000.0 * h + 60000.0 * mn + 1000.0 * s +
                     (double) ms;
         double msecFromEpoch =  86400000.0 * daysSince0AD + msecInDay;
