@@ -1,4 +1,4 @@
-// $Id: Epoch16.java,v 1.3 2010/12/21 16:30:50 liu Exp $
+// $Id: Epoch16.java,v 1.1 2012/05/18 17:47:39 liu Exp $
 package gsfc.nssdc.cdf.util;
 
 import gsfc.nssdc.cdf.CDFException;
@@ -1068,7 +1068,7 @@ public class Epoch16 implements gsfc.nssdc.cdf.CDFConstants {
           daysSince0AD = JulianDay(y,m,d) - 1721060L;
         }
         if (daysSince0AD < 0L)
-          throw new CDFException(ILLEGAL_EPOCH_VALUE);
+          throw new CDFException(ILLEGAL_EPOCH_FIELD);
         ((double[]) epoch)[0] = 86400.0 * daysSince0AD + 3600.0 * h + 60.0 *
                                 mn + (double) s;
         ((double[]) epoch)[1] = (double) msp + Math.pow(10.0, 3.0) * msn +
