@@ -1,4 +1,4 @@
-//$Id: EpochNative.java,v 1.1.1.1 2010/01/13 20:06:14 liu Exp $
+//$Id: EpochNative.java,v 1.1 2012/05/18 17:47:39 liu Exp $
 
 package gsfc.nssdc.cdf.util;
 
@@ -69,8 +69,14 @@ public class EpochNative {
      * Mirrors encodeEPOCH3 from the CDF library. See Section 8.6 of the
      * CDF C Reference Manual Version 2.6 for details
      */
-    public native static String encode3(double epoch);
 
+    public native static String encode3(double epoch);
+    /**
+     * Mirrors encodeEPOCH4 from the CDF library. See Section 8.6 of the
+     * CDF C Reference Manual Version 2.6 for details
+     */
+    public native static String encode4(double epoch);
+    
     /**
      * Mirrors encodeEPOCHx from the CDF library. See Section 8.7 of the
      * CDF C Reference Manual Version 2.6 for details
@@ -101,6 +107,12 @@ public class EpochNative {
      */
     public native static double parse3(String sEpoch);
 
+    /**
+     * Mirrors parseEPOCH from CDF library.  See Section 8.11 of the
+     * CDF C Reference Manual Version 2.6 for details
+     */
+    public native static double parse4(String sEpoch);
+
     static {
 	System.loadLibrary("cdfNativeLibrary");
     }
